version 8.2
clear
set logtype text
set more off
set matsize 600

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl"

capture log close
log using "brazrloc/logs/mlogit-xttrans-aer-natl.log", replace

local maxiter $maxiter


// SUBSIBGE REGRESSIONS

local basendog "subs_tarfoutp subs_tarfintm firm_indexp"  // cut: subs_reffpen
local secexog  "subs_balcadv"
local exoglst  "subs_secrealx subs_fdiflw subs_herfsale"
local cntrlfrm "plant_lnempl plant_indhigh plant_indcoll plant_indwhittot"
local cntrlwrk "tenuryr potexper indprof indtech indwhit indsklb"  // as for accession regressions (omitting tenure)
local ivlst    "subs_ppieu subs_ppinam imp_APD imp_CEE imp_NAM imp_ODV imp_OIN imp_WEU"
local intract1 "subs_tarfoutp_indexp subs_tarfintm_indexp"
local intract2 "subs_tarfoutp_balcadv subs_tarfintm_balcadv"
local intract3 "subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv"
local intract4 "subs_tarfoutp_notindprim subs_tarfintm_notindprim"  // if ~indprim
local intract5 "subs_tarfoutp_indyoung subs_tarfintm_indyoung"  // if potexper < 10
local intract6 "subs_tarfoutp_indwhite subs_tarfintm_indwhite"  // if indprof | indtech | indwhit
local addlreg  "subs_indprown_pis occ_indoutsrc"
local basdsply "subs_tarfoutp_dsplyr subs_tarfintm_dsplyr firm_indexp_dsplyr"  // cut: subs_reffpen_dsplyr
local secdsply "subs_balcadv_dsplyr"
local wrkrexog "indfemal indprim indhigh indscoll indgrad"

* REALLOCATION EXPERIENCE

capture confirm file "brazrloc/data/mlogit-xttrans-natl-subsibge.dta"
if _rc ~= 0 {
use wid ano mes_adm mes_deslig identificad caus_desl_tc fx_etaria sexo rem_media subs_ibge cbogrp temp_empr grau_instr occagg using "brazrloc/data/wid-draw-workers-natl", clear
gen byte indfemal = (sexo==2) // female workers
label var indfemal "Indic.: Female worker"
drop sexo

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* merge aggregate sector and comparative advantage information
rename subs_ibge subsibge
rename ano year
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _m wrld_exp wrld_tot braz_exp braz_tot
rename subsibge subs_ibge
rename year ano
rename balcadv subs_balcadv
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete sector information
drop _m
qui do "brazrloc/auxil/aggsec.do"
label values aggsec aggsec
gen byte tradsec = 7 if aggsec>3
forvalues i=1/5 {
  replace tradsec = `i' if balarank==`i'
  }
label var tradsec "Trade Sectors"
qui do "brazrloc/auxil/tradsec.do"
label values tradsec tradsec
drop balarank

* redefine aggsec to merge agriculture and mining into primary
replace aggsec = 0 if aggsec==1 | aggsec==2

* identify displacement as well as month and sector of first rehiring
sort wid ano mes_adm mes_deslig identificad
gen byte inddspl = (mes_deslig < 13 & caus_desl~=0 & caus_desl~=6 & caus_desl~=7 & caus_desl~=8)
by wid: gen str7 morehir = string(mes_adm[_n+1]) + "/" + string(ano[_n+1]) if inddspl==1
by wid: gen byte indsamsec = (subs_ibge==subs_ibge[_n+1])
by wid: gen byte indnmfsec = (aggsec[_n+1]>3)
label var inddspl "Indic.: Displacement"
label var morehir "Month of first rehiring"
label var indsamsec "Indic.: Same subsec. at rehire"
label var indnmfsec "Indic.: Nonmanf. subs. at rehire"
drop caus_desl_tc

* discard rehirings if plant missing in year before rehiring
sort identificad ano
merge identificad ano using "brazrloc/data/rais-cnpj-list-natl"
tab _m
keep if _m==3
keep wid ano mes_adm mes_deslig identificad aggsec tradsec inddspl morehir indsamsec indnmfsec indabsyr1 rem_media subs_ibge subs_balcadv cbogrp temp_empr fx_etaria grau_instr occagg indfemal
sort wid ano mes_adm mes_deslig identificad
by wid: gen inddisc = indabsyr1[_n+1]
label var inddisc "Plant missing year bef. realloc."
drop indabsyr1

* calculate months from displacement to first rehiring
gen mo2rehir = (int(real(substr(morehir,-4,4))) - ano)*12 + (int(real(substr(morehir,1,index(morehir,"/")-1))) - mes_desl)
replace mo2rehir = 0 if int(real(substr(morehir,-4,4)))==ano & int(real(substr(morehir,1,index(morehir,"/")-1)))<mes_desl
label var mo2rehir "Months to re-employment"
gen byte indnorloc = (mo2rehir > 48 | mo2rehir==.)
label var indnorloc "Indic.: No reall. in 48 months"

* keep last employment per year
rename ano year
egen byte _lastjob = max(mes_deslig), by(wid year)
gen byte indexcl = (mes_deslig~=_lastjob)
label var indexcl "Indic.: Not last job in year"
drop _lastjob

* keep employment with highest pay if more than one last employment per year (random drop for pay ties)
sort wid year indexcl rem_media
by wid year indexcl: replace indexcl=1 if _n~=_N

* drop 1999-2001 and unused variables
drop if year>1998
drop morehir
order wid year mo2rehir

// SECTOR VARIABLES, MAPPING WITH SUBS_IBGE

* merge additional sector information
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/sector-subsibge-data", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
count if _m~=3
if `r(N)'>0  STOP  // incomplete sector-year mapping
drop _m subs_fdistk subs_indunsklb

* reset private-job share before 1995 to 1995
replace subs_indprown_pis = subs_indprown_pis_95 if subs_indprown_pis==.
drop subs_indprown_pis_95

// OCCUPATION VARIABLES

* outsourceable job share
sort cbogrp
merge cbogrp using "brazaux/auxil/cbogrp-outsourcing", nokeep
tab _m  // _m==1: CBO group missing
count if _m~=3 & cbogrp~=.
if `r(N)'>0  STOP  // incomplete CBO mapping
rename indoutsrc occ_indoutsrc
drop _m cbogrp

// PLANT VARIABLES

* merge RAIS information by plant
rename year ano
sort identificad ano
merge identificad ano using "brazrloc/data/rais-cnpj-data-natl", nokeep
tab _m  // _m==1: single worker firms will be omitted from regression with plant-level variables
drop _m
replace plant_n_pis = ln(plant_n_pis)
rename plant_n_pis plant_lnempl
label var plant_lnempl "Log Employment"

// FIRM VARIABLES

* switch to firm level (firm ID)
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"

* merge export status information by firm
sort cnpj_radic ano
merge cnpj_radic ano using "brazaux/secex/brazaux-exporters", nokeep
gen byte indexp = (_merge==3)
replace indexp = . if ano<1990 | ano>2001  // no SECEX information prior to 1990 or after 2001
label define indexp 0 "Nonexporter", modify
label define indexp 1 "Exporter", modify
label var indexp "Indic.: Exporter"
label values indexp indexp
drop _m
rename ano year
rename indexp firm_indexp

* merge PIA information
rename cnpj_radic firm
sort firm year
merge firm year using "brazrloc/data/pia-data"
tab _m
drop if _m==2
drop firm_lntfp firm_ln_cap_empl _m
iis, clear
tis, clear
tsset, clear
rename firm cnpj_radic

// WORKER VARIABLES

* tenure
replace temp_empr = temp_empr/52
rename temp_empr tenuryr
label var tenuryr "Tenure at plant (in years)"
gen tenr2 = tenuryr*tenuryr
label var tenr2 "Quadratic Tenure Term"

* potential experience
gen workrage = 12 if fx_etaria==1
replace workrage =   16 if fx_etaria==2
replace workrage =   21 if fx_etaria==3
replace workrage =   27 if fx_etaria==4
replace workrage = 34.5 if fx_etaria==5
replace workrage = 44.5 if fx_etaria==6
replace workrage =   57 if fx_etaria==7
replace workrage =   .  if fx_etaria==8
label var workrage "Mid-point age in age group"
gen potexper     = workrage -  6 if grau_instr==1
replace potexper = workrage -  7 if grau_instr==2
replace potexper = workrage - 10 if grau_instr==3
replace potexper = workrage - 11 if grau_instr==4
replace potexper = workrage - 14 if grau_instr==5
replace potexper = workrage - 15 if grau_instr==6
replace potexper = workrage - 18 if grau_instr==7
replace potexper = workrage - 19 if grau_instr==8
replace potexper = workrage - 22 if grau_instr==9
label var potexper "Potential labor force experience"
drop workrage fx_etaria
gen potxper2 = potexper*potexper
label var potxper2 "Quadratic Experience Term"

* education indicators
gen byte indprim = (grau_instr==1 | grau_instr==2 | grau_instr==3 | grau_instr==4 | grau_instr==5)
label var indprim "Primary or Middle School Educ."
gen byte indhigh = (grau_instr==6 | grau_instr==7)
label var indhigh "High School Education"
gen byte indscoll = (grau_instr==8)
label var indscoll "Some College Education"
gen byte indgrad = (grau_instr==9)
label var indgrad "Complete College Education"
drop grau_instr

* occupation indicators (based on 3-digit cbo; see rais/cbo/cbogrp2occagg.csv)
gen byte indprof = (occagg==1)
label var indprof "Professional or Managerial Occ."
gen byte indtech = (occagg==2)
label var indtech "Technical or Supervisory Occup."
gen byte indwhit = (occagg==3)
label var indwhit "Other White Collar Occupation"
gen byte indsklb = (occagg==4)
label var indsklb "Skilled Blue Collar Occupation"
gen byte indunsklb = (occagg==5)
label var indunsklb "Unskilled Blue Collar Occupation"
drop occagg

// ANNUAL VARIABLES

* exporting status instruments
sort year
merge year using "brazrloc/auxil/wtf-data", nokeep
count if _m~=3
if `r(N)' > 0  STOP  // years incomplete in wtf-data.dta
drop _m

// FINALIZE ESTIMATION SAMPLE

sort wid year mes_adm mes_deslig rem_media cnpj_radic
drop mes_adm mes_deslig rem_media tenr2 potxper2

* category of rehiring duration
gen byte rehircat = 0 if mo2rehir==0
replace  rehircat = 1 if mo2rehir<=12 & rehircat==.
replace  rehircat = 2 if mo2rehir<=24 & rehircat==.
replace  rehircat = 3 if mo2rehir<=36 & rehircat==.
replace  rehircat = 4 if mo2rehir<=48 & rehircat==.
label var rehircat "Category of rehiring duration"
label define rehircat 0 "Within same month" 1 "Within 1 year" 2 "Within 1 to 2 years" 3 "Within 2 to 3 years" 4 "Within 3 to 4 years", modify
label values rehircat rehircat

* multinomial outcome categories
gen byte mlcat = .
replace mlcat = 1 if mo2rehir<=48 & indsamsec==1
replace mlcat = 2 if mo2rehir<=48 & indsamsec==0
replace mlcat = 3 if mo2rehir<=48 & indnmfsec==1
replace mlcat = 4 if mo2rehir>48 | mo2rehir==.
label var mlcat "Category of Reallocation"
label define mlcat 1 "Same manuf. sector" 2 "Other manuf. sector" 3 "Nonmanuf. sector" 4 "Failure (48mo)", modify
label values mlcat mlcat

* interaction variables and dummies
gen subs_balcadv_tarf = subs_balcadv * subs_tarfoutp
label var subs_balcadv_tarf "subs_balcadv * subs_tarfoutp"
gen firm_indexp_tarf = firm_indexp * subs_tarfoutp
label var firm_indexp_tarf "firm_indexp * subs_tarfoutp"
gen subs_balcadv_indexp = subs_balcadv * firm_indexp
label var subs_balcadv_indexp "subs_balcadv * firm_indexp"
gen subs_balcadv_indexp_tarf = subs_balcadv * subs_tarfoutp * firm_indexp
label var subs_balcadv_indexp_tarf "subs_balcad * _tarfout * _indexp"
qui tab year, generate(indyr_)
qui tab subs_ibge, generate(indsubs_) nolab
drop subs_ibge
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

order wid year rehircat mlcat mo2rehir cnpj_radic aggsec tradsec inddspl inddisc indexcl indsamsec indnmfsec indnorloc subs_balcadv* subs_fdiflw subs_reffpen subs_tarfoutp subs_tarfintm subs_herfsale subs_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_indexp* firm_lnlp tenuryr potexper indfemal indprim indhigh indscoll indgrad indprof indtech indwhit indsklb indunsklb subs_dollar subs_ppieu subs_ppinam
save "brazrloc/data/mlogit-xttrans-natl-subsibge.dta", replace
}

else use "brazrloc/data/mlogit-xttrans-natl-subsibge.dta", clear

// merge displacement fixed-effects from xt_secyrfe0 specification in %03/separations-accession-aer-natl-rr.do
sort wid year
merge wid using "brazrloc/estmat/v4/reg/natl/subsdspl_u.dta"
tab _m
drop if _m==2
drop _m
sort wid year

// keep only last separation per year
drop if indexcl
tab mlcat 
tab mlcat if inddspl~=1

* category redefinition
replace mlcat=0 if inddspl~=1
label define mlcat 0 "notdspl" 1 "samemanf" 2 "othrmanf" 3 "nonmanf" 4 "failure", modify
label values mlcat mlcat

* plant-variable redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* reference year 1998
drop indyr_13

* estimate list for transformed conditional logit
* local estlist "didep:_Imclnum_2 didep:_Imclnum_3 didep:_Imclnum_4 didep:_Imclnum_5 didep:subs_tarfoutp didep:_ImclXsubs__2 didep:_ImclXsubs__3 didep:_ImclXsubs__4 didep:_ImclXsubs__5 didep:subs_tarfintm didep:_ImclXsubs_a2 didep:_ImclXsubs_a3 didep:_ImclXsubs_a4 didep:_ImclXsubs_a5 didep:firm_indexp didep:_ImclXfirm__2 didep:_ImclXfirm__3 didep:_ImclXfirm__4 didep:_ImclXfirm__5 didep:indsubs_2 didep:indsubs_3 didep:indsubs_4 didep:indsubs_5 didep:indsubs_6 didep:indsubs_7 didep:indsubs_8 didep:indsubs_9 didep:indsubs_10 didep:indsubs_11 didep:indsubs_13 didep:indyr_5 didep:indyr_6 didep:indyr_7 didep:indyr_8 didep:indyr_9 didep:indyr_10 didep:indyr_11 didep:indyr_12"
tsunab trdsubs : trd_indsubs*
local estlist "_Imclnum_2 _Imclnum_3 _Imclnum_4 _Imclnum_5 subs_tarfoutp _ImclXsubs__2 _ImclXsubs__3 _ImclXsubs__4 _ImclXsubs__5 subs_tarfintm _ImclXsubs_a2 _ImclXsubs_a3 _ImclXsubs_a4 _ImclXsubs_a5 firm_indexp _ImclXfirm__2 _ImclXfirm__3 _ImclXfirm__4 _ImclXfirm__5 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_13 indyr_5 indyr_6 indyr_7 indyr_8 i'ndyr_9 indyr_10 indyr_11 indyr_12 `trdsubs' u_dspl"

* regressor list for standard logit
local varlist "subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv subs_reffpen subs_secrealx subs_fdiflw subs_herfsale plant_lnempl plant_indcoll plant_indhigh plant_indwhittot tenuryr potexper indprof indtech indwhit indsklb indunsklb indfemal indprim indhigh indscoll indgrad udspl subs_tarfoutp_indexp subs_tarfintm_indexp subs_tarfoutp_balcadv subs_tarfintm_balcadv  subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv  subs_tarfoutp_notindprim subs_tarfintm_notindprim  subs_tarfoutp_indyoung subs_tarfintm_indyoung subs_tarfoutp_indwhite subs_tarfintm_indwhite  subs_tarfoutp_indfemal subs_tarfintm_indfemal subs_indprown_pis occ_indoutsrc subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 trd_indsubs_1 trd_indsubs_2 trd_indsubs_3 trd_indsubs_4 trd_indsubs_5 trd_indsubs_6 trd_indsubs_7 trd_indsubs_8 trd_indsubs_9 trd_indsubs_10 trd_indsubs_11 trd_indsubs_12 trd_indsubs_13 trd_indsubs_14 trd_indsubs_15 trd_indsubs_16 trd_indsubs_17 trd_indsubs_18 trd_indsubs_19 trd_indsubs_20 trd_indsubs_21 trd_indsubs_22 trd_indsubs_23 trd_indsubs_24 trd_indsubs_25 trd_indsubs_26"
local varle : list sizeof varlist
tokenize `varlist'
local eqlist ""
foreach eq in "notdspl" "samemanf" "othrmanf" "nonmanf" "failure" {
  forvalues i = 1/`varle' {
    local eqlist "`eqlist' `eq':``i''"
    }
  }
* disp "`eqlist'"


// transformed conditional logit

* duplicates report wid year
drop if year<1990
keep wid year mlcat `basendog' `exoglst' `cntrlfrm' `cntrlwrk' `wrkrexog' indyr* indsubs* inddspl trd_indsubs* u_dspl
gen stratum=_n  // wid-year identified observations
expand 5
sort stratum
gen byte mclnum = mod(_n-1,5)+1
gen byte didep = (mlcat==mclnum)
* xi results in natural coding, _Imlcat_1 omitted (baseoutcome)
local reglst ""
foreach var in `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' {
  local reglist = "`reglst' i.mclnum|`var'"
  }  
* xi: clogit didep i.mclnum `reglst' indsubs* indyr*, group(wid) robust iterate(`maxiter')   // stratum has no within-group variance

* all-worker regression, baseline: no separation, with year and sector-fixed effects
xi: clogit didep i.mclnum i.mclnum|subs_tarfoutp i.mclnum|subs_tarfintm i.mclnum|firm_indexp indsubs* indyr*, group(wid) robust iterate(`maxiter')
est2vec mcl_xttrans, vars(`estlist') e(N r2_p chi2 df_m) name(all_secyrfe)

* displaced-worker regression, baseline: same sectorm, with year and sector-fixed effects
xi: clogit didep i.mclnum i.mclnum|subs_tarfoutp i.mclnum|subs_tarfintm i.mclnum|firm_indexp indsubs* indyr* if inddspl==1, group(wid) robust iterate(`maxiter')
est2vec mcl_xttrans, addto(mcl_xttrans) name(dspl_secyrfe)

* all-worker regression, baseline: no separation, with year effects and sector trends
xi: clogit didep i.mclnum i.mclnum|subs_tarfoutp i.mclnum|subs_tarfintm i.mclnum|firm_indexp indsubs* indyr* trd_indsubs*, group(wid) robust iterate(`maxiter')
est2vec mcl_xttrans, addto(mcl_xttrans) name(all_secyrtrdfe)

* displaced-worker regression, baseline: same sectorm, with year effects and sector trends
xi: clogit didep i.mclnum i.mclnum|subs_tarfoutp i.mclnum|subs_tarfintm i.mclnum|firm_indexp indsubs* indyr* trd_indsubs* if inddspl==1, group(wid) robust iterate(`maxiter')
est2vec mcl_xttrans, addto(mcl_xttrans) name(dspl_secyrtrdfe)


// no worker-fixed effects

* all-worker regression, baseline: no separation, with year and sector-fixed effects
mlogit mlcat `basendog' `exoglst' `cntrlfrm' `cntrlwrk' `wrkrexog' indyr* indsubs* if year>=1990, robust iterate(`maxiter') baseoutcome(0)
est2vec ml_xttrans, vars(`eqlist') e(N r2_p chi2 df_m) name(all_secyrfe)

* displaced-worker regression, baseline: same sector, with year and sector-fixed effects
mlogit mlcat `basendog' `exoglst' `cntrlfrm' `cntrlwrk' `wrkrexog' indyr* indsubs* if year>=1990 & inddspl==1, robust iterate(`maxiter') baseoutcome(1)
est2vec ml_xttrans, addto(ml_xttrans) name(dspl_secyrfe)

* all-worker regression, baseline: no separation, with year effects and sector trends
mlogit mlcat `basendog' `exoglst' `cntrlfrm' `cntrlwrk' `wrkrexog' indyr* indsubs* trd_indsubs* if year>=1990, robust iterate(`maxiter') baseoutcome(0)
est2vec ml_xttrans, addto(ml_xttrans) name(all_secyrtrdfe)

* displaced-worker regression, baseline: same sectorm, with year effects and sector trends
mlogit mlcat `basendog' `exoglst' `cntrlfrm' `cntrlwrk' `wrkrexog' indyr* indsubs* trd_indsubs* if year>=1990 & inddspl==1, robust iterate(`maxiter') baseoutcome(1)
est2vec ml_xttrans, addto(ml_xttrans) name(dspl_secyrtrdfe)


// predicted worker-fixed effects (from xt_secyrfe0 specification in %03/separations-accession-aer-natl-rr.do)

* all-worker regression, baseline: no separation, with year and sector-fixed effects
mlogit mlcat `basendog' `exoglst' `cntrlfrm' `cntrlwrk' `wrkrexog' u_dspl indyr* indsubs* if year>=1990, robust iterate(`maxiter') baseoutcome(0)
est2vec ml_xttrans, addto(ml_xttrans) name(all_secyrfe_uhat)

* displaced-worker regression, baseline: same sectorm, with year and sector-fixed effects
mlogit mlcat `basendog' `exoglst' `cntrlfrm' `cntrlwrk' `wrkrexog' u_dspl indyr* indsubs* if year>=1990 & inddspl==1, robust iterate(`maxiter') baseoutcome(1)
est2vec ml_xttrans, addto(ml_xttrans) name(dspl_secyrfe_uhat)

* all-worker regression, baseline: no separation, with year effects and sector trends
mlogit mlcat `basendog' `exoglst' `cntrlfrm' `cntrlwrk' `wrkrexog' u_dspl indyr* indsubs* trd_indsubs* if year>=1990, robust iterate(`maxiter') baseoutcome(0)
est2vec ml_xttrans, addto(ml_xttrans) name(all_secyrtrdfe_uhat)

* displaced-worker regression, baseline: same sectorm, with year effects and sector trends
mlogit mlcat `basendog' `exoglst' `cntrlfrm' `cntrlwrk' `wrkrexog' u_dspl indyr* indsubs* trd_indsubs* if year>=1990 & inddspl==1, robust iterate(`maxiter') baseoutcome(1)
est2vec ml_xttrans, addto(ml_xttrans) name(dspl_secyrtrdfe_uhat)


// Save results

foreach type in b se e {
  matsave mcl_xttrans_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  matsave ml_xttrans_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  }

log close
