version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl"
capture mkdir "brazrloc/tex/v4/gdp"

capture log close
log using "brazrloc/logs/prediction-stats-aerrr-natl.log", replace

local maxiter $maxiter


// SUBSIBGE REGRESSIONS

local basendog "subs_tarfoutp subs_tarfintm firm_indexp"  // cut: subs_reffpen
local secexog  "subs_balcadv"
local secexo90 "subs_balcadv_90"
local exoglst  "subs_secrealx subs_fdiflw subs_herfsale"
local cntrlfrm "plant_lnempl plant_indhigh plant_indcoll plant_indwhittot"
local ivlst    "subs_ppieu subs_ppinam imp_APD imp_CEE imp_NAM imp_ODV imp_OIN imp_WEU"
local intract1 "subs_tarfoutp_indexp subs_tarfintm_indexp"
local intract2 "subs_tarfoutp_balcadv subs_tarfintm_balcadv"
local intract2_90  "subs_tarfoutp_balcadv_90 subs_tarfintm_balcadv_90"
local intract3 "subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv"
local intract3_90  "subs_tarfoutp_indexp_balcadv_90 subs_tarfintm_indexp_balcadv_90"
local intract4 "subs_tarfoutp_notindprim subs_tarfintm_notindprim"  // if ~indprim
local intract5 "subs_tarfoutp_indyoung subs_tarfintm_indyoung"  // if potexper < 10
local intract6 "subs_tarfoutp_indwhite subs_tarfintm_indwhite"  // if indprof | indtech | indwhit
local intract7 "subs_tarfoutp_indfemal subs_tarfintm_indfemal"  // if indfemal
local intract8 "subs_tarfoutp_notindprim subs_tarfintm_notindprim firm_indexp_notindprim subs_balcadv_notindprim"
local intract9 "subs_tarfoutp_indexp_notindprim subs_tarfoutp_balcadv_notindprim subs_tarfintm_indexp_notindprim subs_tarfintm_balcadv_notindprim"
local addlreg  "subs_indprown_pis occ_indoutsrc"


* SEPARATIONS NATL

// coefficient estimates: subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp `intract1' `intract2_90' `intract3_90' `intract4' `intract5' `intract6' `intract7'
matload subsdspl_aerrr_b, p(brazrloc/estmat/v4/reg/natl) over dropall missing(.)
matins subsdspl_aerrr_b, m(subs_dspl) ifr(subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp `intract1' `intract2_90' `intract3_90' `intract4' `intract5' `intract6' `intract7') over
matorder subs_dspl, m(subs_dspl) ifc(clogit_secyrfe0 clogit_secyrfe clogit_nofe clogit_secfe_auxyr xt_secyrfe0 xtiv_secyrfe0) over
mat drop subsdspl_aerrr_b
matload subsdspl_aerrr_intract_b, p(brazrloc/estmat/v4/reg/natl) over dropall missing(.)
matins subsdspl_aerrr_intract_b, m(subs_dspl_intr) ifr(subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp `intract1' `intract2_90' `intract3_90' `intract4' `intract5' `intract6' `intract7') over
matorder subs_dspl_intr, m(subs_dspl_intr) ifc(clogit_intract30_90 clogit_intract30_90_reffpen clogit_intract70) over
mat subs_dspl = subs_dspl , subs_dspl_intr
mat drop subsdspl_aerrr_intract_b subs_dspl_intr
local rows = rowsof(subs_dspl)
local cols = colsof(subs_dspl)
forvalues i = 1/`rows' {
  forvalues j = 1/`cols' {
    if subs_dspl[`i',`j']==.  mat subs_dspl[`i',`j']=0
    }
  }

// clogit sample (with recreated sector codes)
use if ~indexcl using "brazrloc/data/separations-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf indlayoff indquit
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }
* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim
* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"
* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }
* merge Balassa quintiles
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep keep(balarank)
tab _m  // _m==1: workers in nontraded goods sectors
drop _m
rename subsibge subs_ibge
* reference year 1998
drop indyr_13
* subs_balcadv_90
foreach var in subs_balcadv balarank {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var balarank_90 "Quintile rank Balassa adv. 1990"
drop subs_ibge balarank
* interactions
gen subs_tarfoutp_indexp = subs_tarfoutp * firm_indexp
label var subs_tarfoutp_indexp "tarfoutp * indexp"
gen subs_tarfintm_indexp = subs_tarfintm * firm_indexp
label var subs_tarfintm_indexp "tarfintm * indexp"
gen subs_tarfoutp_balcadv = subs_tarfoutp * subs_balcadv
label var subs_tarfoutp_balcadv "tarfoutp * balcadv"
gen subs_tarfintm_balcadv = subs_tarfintm * subs_balcadv
label var subs_tarfintm_balcadv "tarfintm * balcadv"
gen subs_tarfoutp_indexp_balcadv = subs_tarfoutp * firm_indexp * subs_balcadv
label var subs_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen subs_tarfintm_indexp_balcadv = subs_tarfintm * firm_indexp * subs_balcadv
label var subs_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen subs_tarfoutp_notindprim = subs_tarfoutp * (~indprim) // if ~indprim
label var subs_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen subs_tarfintm_notindprim = subs_tarfintm * (~indprim) // if ~indprim
label var subs_tarfintm_notindprim "tarfintm * (~indprim)"
gen firm_indexp_notindprim = firm_indexp * (~indprim) // if ~indprim
label var firm_indexp_notindprim "indexp * (~indprim)"
gen subs_balcadv_notindprim = subs_balcadv * (~indprim) // if ~indprim
label var subs_balcadv_notindprim "balcadv * (~indprim)"
gen subs_tarfoutp_indexp_notindprim = subs_tarfoutp * firm_indexp * (~indprim) // if ~indprim
label var subs_tarfoutp_indexp_notindprim "tarfoutp * indexp * (~indprim)"
gen subs_tarfoutp_balcadv_notindprim = subs_tarfoutp * subs_balcadv * (~indprim) // if ~indprim
label var subs_tarfoutp_balcadv_notindprim "tarfoutp * balcadv * (~indprim)"
gen subs_tarfintm_indexp_notindprim = subs_tarfintm * firm_indexp * (~indprim) // if ~indprim
label var subs_tarfintm_indexp_notindprim "tarfintm * indexp * (~indprim)"
gen subs_tarfintm_balcadv_notindprim = subs_tarfintm * subs_balcadv * (~indprim) // if ~indprim
label var subs_tarfintm_balcadv_notindprim "tarfintm * balcadv * (~indprim)"
gen subs_tarfoutp_indyoung = subs_tarfoutp * (potexper<10) // if potexper < 10
label var subs_tarfoutp_indyoung "subs_tarfoutp * (potexper<10)"
gen subs_tarfintm_indyoung = subs_tarfintm * (potexper<10) // if potexper < 10
label var subs_tarfintm_indyoung "subs_tarfintm * (potexper<10)"
gen subs_tarfoutp_indwhite = subs_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfoutp_indwhite "subs_tarfoutp * (indwhit+)"
gen subs_tarfintm_indwhite = subs_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfintm_indwhite "subs_tarfintm * (indwhit+)"
gen subs_tarfoutp_indfemal = subs_tarfoutp * (indfemal) // if indfemal
label var subs_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen subs_tarfintm_indfemal = subs_tarfintm * (indfemal) // if indfemal
label var subs_tarfintm_indfemal "tarfintm * (indfemal)"
gen subs_tarfoutp_balcadv_90 = subs_tarfoutp * subs_balcadv_90
label var subs_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen subs_tarfintm_balcadv_90 = subs_tarfintm * subs_balcadv_90
label var subs_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen subs_tarfoutp_indexp_balcadv_90 = subs_tarfoutp * firm_indexp * subs_balcadv_90
label var subs_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen subs_tarfintm_indexp_balcadv_90 = subs_tarfintm * firm_indexp * subs_balcadv_90
label var subs_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"

* dspl-clogit-secyrfe0
clogit inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
qui predict phatsecyr, p
* dspl-clogit-yrfe
clogit inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
qui predict phatyr, p
* clogit-intract30_90
clogit inddspl `basendog' `intract1' `intract2_90' `intract3_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
qui predict phatitr3, p
* clogit-intract70
clogit inddspl `basendog' `intract4' `intract5' `intract6' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
qui predict phatitr7, p

// sample means: subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp subs_balcadv subs_balcadv_90 subs_balcadv_q5 notindprim indyoung indwhite indfemal indexp_balcadv indexp_balcadv_90 `intract1' `intract2_90' `intract3_90' `intract4' `intract5' `intract6' `intract7' inddspl phatsecyr phatyr phatitr3 phatitr7
gen byte notindprim = (~indprim)
gen byte indyoung = (potexper<10)
gen byte indwhite = (indprof|indtech|indwhit)
gen indexp_balcadv = firm_indexp * subs_balcadv
gen indexp_balcadv_90 = firm_indexp * subs_balcadv_90
gen subs_balcadv_q5 = subs_balcadv_90 if balarank_90==5
gen byte subsibge = .
forvalues i = 1/26 {
  qui replace subsibge = `i' if indsubs_`i'==1
  }
local cnt : word count subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp subs_balcadv subs_balcadv_90 subs_balcadv_q5 notindprim indyoung indwhite indfemal indexp_balcadv indexp_balcadv_90 `intract1' `intract2_90' `intract3_90' `intract4' `intract5' `intract6' `intract7' inddspl phatsecyr phatyr phatitr3 phatitr7
foreach yr in 90 92 94 98 {
  mat tradvars`yr' = J(`cnt',27,.)
  local i 0
  foreach var in subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp subs_balcadv subs_balcadv_90 subs_balcadv_q5 notindprim indyoung indwhite indfemal indexp_balcadv indexp_balcadv_90 `intract1' `intract2_90' `intract3_90' `intract4' `intract5' `intract6' `intract7' inddspl phatsecyr phatyr phatitr3 phatitr7 {
    local i = `i' + 1
    matname tradvars`yr' `var', rows(`i') explicit
    matname tradvars`yr' yr`yr':allsec, columns(1) explicit
    if substr("`var'",1,4)~="phat" {
      qui summ `var' if year==19`yr' & indsmpl
      disp in gr "Coefficient of variation of " in ye "`var'" in gr " in " in ye "19`yr'" in gr ": " in ye `r(sd)'/`r(mean)'
      }
    else qui summ `var' if indsmpl, meanonly
    mat tradvars`yr'[`i',1] = r(mean)
    forvalues subsec = 1/26 {
      local namesec "sec`subsec'"
      if `subsec'<10  local namesec "sec0`subsec'"
      local col = `subsec' + 1
      matname tradvars`yr' yr`yr':`namesec', columns(`col') explicit
      qui summ `var' if year==19`yr' & subsibge==`subsec' & indsmpl, meanonly
      mat tradvars`yr'[`i',`col'] = r(mean)
      }
    }
  }
* drop notindprim indyoung indwhite indexp_balcadv subsibge
# delimit ;
local rownames : rownames subs_dspl;
local rows = rowsof(subs_dspl);
foreach yr in 92 94 98 {;
  mat tradvdif`yr'90 = tradvars`yr' - tradvars90;
  // predall;
  matins tradvdif`yr'90, m(tradvdifuse) ifr(`rownames') over;
  mat predall`yr'90 = subs_dspl ' * tradvdifuse;
  // predtrad;
  mat idmat_trad = I(`rows');
  mat rownames idmat_trad = `rownames';
  mat colnames idmat_trad = `rownames';
  local tradvars "";
  foreach var of local rownames {;
    if substr("`var'",- 8, 8)=="_balcadv" {;           local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"subs_balcadv"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _subs_balcadv, columns(`col') explicit; };
    if substr("`var'",-11,11)=="_balcadv_90" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"subs_balcadv_90"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _subs_balcadv_90, columns(`col') explicit; };
    if substr("`var'",-15,15)=="_indexp_balcadv" {;    local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"subs_balcadv"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _subs_balcadv, columns(`col') explicit; };
    if substr("`var'",-18,18)=="_indexp_balcadv_90" {; local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"subs_balcadv_90"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _subs_balcadv_90, columns(`col') explicit; };
    if substr("`var'",-11,11)=="_notindprim" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"notindprim"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _notindprim, columns(`col') explicit; };
    if substr("`var'",- 9, 9)=="_indyoung" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indyoung"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indyoung, columns(`col') explicit; };
    if substr("`var'",- 9, 9)=="_indwhite" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indwhite"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indwhite, columns(`col') explicit; };
    if substr("`var'",- 9, 9)=="_indfemal" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indfemal"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indfemal, columns(`col') explicit; };
    if index("`var'","subs_tarfoutp_indexp")>0  local tradvars "`tradvars' subs_tarfoutp_indexp";
    if index("`var'","subs_tarfoutp")>0 & index("`var'","subs_tarfoutp_indexp")==0  local tradvars "`tradvars' subs_tarfoutp";
    if index("`var'","subs_tarfintm_indexp")>0  local tradvars "`tradvars' subs_tarfintm_indexp";
    if index("`var'","subs_tarfintm")>0 & index("`var'","subs_tarfintm_indexp")==0  local tradvars "`tradvars' subs_tarfintm";
    if index("`var'","subs_reffpen")>0   local tradvars "`tradvars' subs_reffpen";
    if index("`var'","firm_indexp")>0    local tradvars "`tradvars' firm_indexp";
    };
  matins tradvdif`yr'90, m(tradvdifuse) ifr(`tradvars') over;
  mat predtrad`yr'90 = ( idmat_trad * subs_dspl )' * tradvdifuse;
  // predtarf;
  mat idmat_tarf = I(`rows');
  mat rownames idmat_tarf = `rownames';
  mat colnames idmat_tarf = `rownames';
  local tradvars "";
  foreach var of local rownames {;
    if substr("`var'",-11,11)=="firm_indexp" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = 0; matname idmat_trad 0, columns(`col') explicit; };
    if substr("`var'",- 8, 8)=="_balcadv" {;           local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"subs_balcadv"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _subs_balcadv, columns(`col') explicit; };
    if substr("`var'",-11,11)=="_balcadv_90" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"subs_balcadv_90"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _subs_balcadv_90, columns(`col') explicit; };
    if substr("`var'",-16,16)=="_tarfoutp_indexp" {;   local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"firm_indexp"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _firm_indexp, columns(`col') explicit; };
    if substr("`var'",-16,16)=="_tarfintm_indexp" {;   local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"firm_indexp"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _firm_indexp, columns(`col') explicit; };
    if substr("`var'",-15,15)=="_indexp_balcadv" {;    local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indexp_balcadv"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indexp_balcadv, columns(`col') explicit; };
    if substr("`var'",-18,18)=="_indexp_balcadv_90" {; local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indexp_balcadv_90"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indexp_balcadv_90, columns(`col') explicit; };
    if substr("`var'",-11,11)=="_notindprim" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"notindprim"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _notindprim, columns(`col') explicit; };
    if substr("`var'",- 9, 9)=="_indyoung" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indyoung"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indyoung, columns(`col') explicit; };
    if substr("`var'",- 9, 9)=="_indwhite" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indwhite"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indwhite, columns(`col') explicit; };
    if substr("`var'",- 9, 9)=="_indfemal" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indfemal"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indfemal, columns(`col') explicit; };
    if index("`var'","subs_tarfoutp_indexp_balcadv_90")>0  local tradvars "`tradvars' subs_tarfoutp";
    if index("`var'","subs_tarfoutp")>0 & index("`var'","subs_tarfoutp_indexp_balcadv_90")==0  local tradvars "`tradvars' subs_tarfoutp";
    if index("`var'","subs_tarfintm_indexp_balcadv_90")>0  local tradvars "`tradvars' subs_tarfintm";
    if index("`var'","subs_tarfintm")>0 & index("`var'","subs_tarfintm_indexp_balcadv_90")==0  local tradvars "`tradvars' subs_tarfintm";
    if index("`var'","subs_reffpen")>0   local tradvars "`tradvars' subs_reffpen";
    if index("`var'","firm_indexp")>0    local tradvars "`tradvars' firm_indexp";
    };
  matins tradvdif`yr'90, m(tarfvdifuse) ifr(`tradvars') over;
  mat predtarf`yr'90 = ( idmat_tarf * subs_dspl )' * tarfvdifuse;
  };
# delimit cr

// report results
mat list subs_dspl
mat list tradvdif9890
mat list predall9890
mat list predtrad9890
mat list predtarf9890
mat list tradvdif9490
mat list predall9490
mat list predtrad9490
mat list predtarf9490

// rename matrices to keep results
mat rename subs_dspl subsdspl_coef_tbl
mat rename tradvars90 subsdspl_tradvars90_tbl
mat rename tradvars92 subsdspl_tradvars92_tbl
mat rename tradvars94 subsdspl_tradvars94_tbl
mat rename tradvars98 subsdspl_tradvars98_tbl


* ACCESSIONS NATL

// coefficient estimates: subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp `intract1' `intract2_90' `intract3_90' `intract4' `intract5' `intract6' `intract7'
matload subshire_aerrr_b, p(brazrloc/estmat/v4/reg/natl) over dropall missing(.)
matins subshire_aerrr_b, m(subs_hire) ifr(subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp `intract1' `intract2_90' `intract3_90' `intract4' `intract5' `intract6' `intract7') over
matorder subs_hire, m(subs_hire) ifc(clogit_secyrfe0 clogit_secyrfe clogit_nofe clogit_secfe_auxyr xt_secyrfe0 xtiv_secyrfe0) over
mat drop subshire_aerrr_b
matload subshire_aerrr_intract_b, p(brazrloc/estmat/v4/reg/natl) over dropall missing(.)
matins subshire_aerrr_intract_b, m(subs_hire_intr) ifr(subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp `intract1' `intract2_90' `intract3_90' `intract4' `intract5' `intract6' `intract7') over
matorder subs_hire_intr, m(subs_hire_intr) ifc(clogit_intract30_90 clogit_intract30_90_reffpen clogit_intract70) over
mat subs_hire = subs_hire , subs_hire_intr
mat drop subshire_aerrr_intract_b subs_hire_intr
local rows = rowsof(subs_hire)
local cols = colsof(subs_hire)
forvalues i = 1/`rows' {
  forvalues j = 1/`cols' {
    if subs_hire[`i',`j']==.  mat subs_hire[`i',`j']=0
    }
  }

// clogit sample (with recreated sector codes)
use if ~indexcl using "brazrloc/data/accessions-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }
* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim
* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"
* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }
* merge Balassa quintiles
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep keep(balarank)
tab _m  // _m==1: workers in nontraded goods sectors
drop _m
rename subsibge subs_ibge
* reference year 1998
drop indyr_13
* subs_balcadv_90
foreach var in subs_balcadv balarank {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var balarank_90 "Quintile rank Balassa adv. 1990"
drop subs_ibge balarank
* interactions
gen subs_tarfoutp_indexp = subs_tarfoutp * firm_indexp
label var subs_tarfoutp_indexp "tarfoutp * indexp"
gen subs_tarfintm_indexp = subs_tarfintm * firm_indexp
label var subs_tarfintm_indexp "tarfintm * indexp"
gen subs_tarfoutp_balcadv = subs_tarfoutp * subs_balcadv
label var subs_tarfoutp_balcadv "tarfoutp * balcadv"
gen subs_tarfintm_balcadv = subs_tarfintm * subs_balcadv
label var subs_tarfintm_balcadv "tarfintm * balcadv"
gen subs_tarfoutp_indexp_balcadv = subs_tarfoutp * firm_indexp * subs_balcadv
label var subs_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen subs_tarfintm_indexp_balcadv = subs_tarfintm * firm_indexp * subs_balcadv
label var subs_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen subs_tarfoutp_notindprim = subs_tarfoutp * (~indprim) // if ~indprim
label var subs_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen subs_tarfintm_notindprim = subs_tarfintm * (~indprim) // if ~indprim
label var subs_tarfintm_notindprim "tarfintm * (~indprim)"
gen firm_indexp_notindprim = firm_indexp * (~indprim) // if ~indprim
label var firm_indexp_notindprim "indexp * (~indprim)"
gen subs_balcadv_notindprim = subs_balcadv * (~indprim) // if ~indprim
label var subs_balcadv_notindprim "balcadv * (~indprim)"
gen subs_tarfoutp_indexp_notindprim = subs_tarfoutp * firm_indexp * (~indprim) // if ~indprim
label var subs_tarfoutp_indexp_notindprim "tarfoutp * indexp * (~indprim)"
gen subs_tarfoutp_balcadv_notindprim = subs_tarfoutp * subs_balcadv * (~indprim) // if ~indprim
label var subs_tarfoutp_balcadv_notindprim "tarfoutp * balcadv * (~indprim)"
gen subs_tarfintm_indexp_notindprim = subs_tarfintm * firm_indexp * (~indprim) // if ~indprim
label var subs_tarfintm_indexp_notindprim "tarfintm * indexp * (~indprim)"
gen subs_tarfintm_balcadv_notindprim = subs_tarfintm * subs_balcadv * (~indprim) // if ~indprim
label var subs_tarfintm_balcadv_notindprim "tarfintm * balcadv * (~indprim)"
gen subs_tarfoutp_indyoung = subs_tarfoutp * (potexper<10) // if potexper < 10
label var subs_tarfoutp_indyoung "subs_tarfoutp * (potexper<10)"
gen subs_tarfintm_indyoung = subs_tarfintm * (potexper<10) // if potexper < 10
label var subs_tarfintm_indyoung "subs_tarfintm * (potexper<10)"
gen subs_tarfoutp_indwhite = subs_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfoutp_indwhite "subs_tarfoutp * (indwhit+)"
gen subs_tarfintm_indwhite = subs_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfintm_indwhite "subs_tarfintm * (indwhit+)"
gen subs_tarfoutp_indfemal = subs_tarfoutp * (indfemal) // if indfemal
label var subs_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen subs_tarfintm_indfemal = subs_tarfintm * (indfemal) // if indfemal
label var subs_tarfintm_indfemal "tarfintm * (indfemal)"
gen subs_tarfoutp_balcadv_90 = subs_tarfoutp * subs_balcadv_90
label var subs_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen subs_tarfintm_balcadv_90 = subs_tarfintm * subs_balcadv_90
label var subs_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen subs_tarfoutp_indexp_balcadv_90 = subs_tarfoutp * firm_indexp * subs_balcadv_90
label var subs_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen subs_tarfintm_indexp_balcadv_90 = subs_tarfintm * firm_indexp * subs_balcadv_90
label var subs_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"

* hire-clogit-secyrfe0
clogit indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
qui predict phatsecyr, p
* hire-clogit-yrfe
clogit indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
qui predict phatyr, p
* clogit-intract30_90
clogit indhire `basendog' `intract1' `intract2_90' `intract3_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
qui predict phatitr3, p
* clogit-intract70
clogit indhire `basendog' `intract4' `intract5' `intract6' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
qui predict phatitr7, p

// sample means: subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp subs_balcadv subs_balcadv_90 subs_balcadv_q5 notindprim indyoung indwhite indfemal indexp_balcadv indexp_balcadv_90 `intract1' `intract2_90' `intract3_90' `intract4' `intract5' `intract6' `intract7' indhire phatsecyr phatyr phatitr3 phatitr7
gen byte notindprim = (~indprim)
gen byte indyoung = (potexper<10)
gen byte indwhite = (indprof|indtech|indwhit)
gen indexp_balcadv = firm_indexp * subs_balcadv
gen indexp_balcadv_90 = firm_indexp * subs_balcadv_90
gen subs_balcadv_q5 = subs_balcadv_90 if balarank_90==5
gen byte subsibge = .
forvalues i = 1/26 {
  qui replace subsibge = `i' if indsubs_`i'==1
  }
local cnt : word count subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp subs_balcadv subs_balcadv_90 subs_balcadv_q5 notindprim indyoung indwhite indfemal indexp_balcadv indexp_balcadv_90 `intract1' `intract2_90' `intract3_90' `intract4' `intract5' `intract6' `intract7' indhire phatsecyr phatyr phatitr3 phatitr7
foreach yr in 90 92 94 98 {
  mat tradvars`yr' = J(`cnt',27,.)
  local i 0
  foreach var in subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp subs_balcadv subs_balcadv_90 subs_balcadv_q5 notindprim indyoung indwhite indfemal indexp_balcadv indexp_balcadv_90 `intract1' `intract2_90' `intract3_90' `intract4' `intract5' `intract6' `intract7' indhire phatsecyr phatyr phatitr3 phatitr7 {
    local i = `i' + 1
    matname tradvars`yr' `var', rows(`i') explicit
    matname tradvars`yr' yr`yr':allsec, columns(1) explicit
    if substr("`var'",1,4)~="phat" {
      qui summ `var' if year==19`yr' & indsmpl
      disp in gr "Coefficient of variation of " in ye "`var'" in gr " in " in ye "19`yr'" in gr ": " in ye `r(sd)'/`r(mean)'
      }
    else qui summ `var' if indsmpl, meanonly
    mat tradvars`yr'[`i',1] = r(mean)
    forvalues subsec = 1/26 {
      local namesec "sec`subsec'"
      if `subsec'<10  local namesec "sec0`subsec'"
      local col = `subsec' + 1
      matname tradvars`yr' yr`yr':`namesec', columns(`col') explicit
      qui summ `var' if year==19`yr' & subsibge==`subsec' & indsmpl, meanonly
      mat tradvars`yr'[`i',`col'] = r(mean)
      }
    }
  }
* drop notindprim indyoung indwhite indexp_balcadv subsibge
# delimit ;
local rownames : rownames subs_hire;
local rows = rowsof(subs_hire);
foreach yr in 92 94 98 {;
  mat tradvdif`yr'90 = tradvars`yr' - tradvars90;
  // predall;
  matins tradvdif`yr'90, m(tradvdifuse) ifr(`rownames') over;
  mat predall`yr'90 = subs_hire ' * tradvdifuse;
  // predtrad;
  mat idmat_trad = I(`rows');
  mat rownames idmat_trad = `rownames';
  mat colnames idmat_trad = `rownames';
  local tradvars "";
  foreach var of local rownames {;
    if substr("`var'",- 8, 8)=="_balcadv" {;           local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"subs_balcadv"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _subs_balcadv, columns(`col') explicit; };
    if substr("`var'",-11,11)=="_balcadv_90" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"subs_balcadv_90"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _subs_balcadv_90, columns(`col') explicit; };
    if substr("`var'",-15,15)=="_indexp_balcadv" {;    local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"subs_balcadv"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _subs_balcadv, columns(`col') explicit; };
    if substr("`var'",-18,18)=="_indexp_balcadv_90" {; local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"subs_balcadv_90"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _subs_balcadv_90, columns(`col') explicit; };
    if substr("`var'",-11,11)=="_notindprim" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"notindprim"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _notindprim, columns(`col') explicit; };
    if substr("`var'",- 9, 9)=="_indyoung" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indyoung"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indyoung, columns(`col') explicit; };
    if substr("`var'",- 9, 9)=="_indwhite" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indwhite"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indwhite, columns(`col') explicit; };
    if substr("`var'",- 9, 9)=="_indfemal" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indfemal"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indfemal, columns(`col') explicit; };
    if index("`var'","subs_tarfoutp_indexp")>0  local tradvars "`tradvars' subs_tarfoutp_indexp";
    if index("`var'","subs_tarfoutp")>0 & index("`var'","subs_tarfoutp_indexp")==0  local tradvars "`tradvars' subs_tarfoutp";
    if index("`var'","subs_tarfintm_indexp")>0  local tradvars "`tradvars' subs_tarfintm_indexp";
    if index("`var'","subs_tarfintm")>0 & index("`var'","subs_tarfintm_indexp")==0  local tradvars "`tradvars' subs_tarfintm";
    if index("`var'","subs_reffpen")>0   local tradvars "`tradvars' subs_reffpen";
    if index("`var'","firm_indexp")>0    local tradvars "`tradvars' firm_indexp";
    };
  matins tradvdif`yr'90, m(tradvdifuse) ifr(`tradvars') over;
  mat predtrad`yr'90 = ( idmat_trad * subs_hire )' * tradvdifuse;
  // predtarf;
  mat idmat_tarf = I(`rows');
  mat rownames idmat_tarf = `rownames';
  mat colnames idmat_tarf = `rownames';
  local tradvars "";
  foreach var of local rownames {;
    if substr("`var'",-11,11)=="firm_indexp" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = 0; matname idmat_trad 0, columns(`col') explicit; };
    if substr("`var'",- 8, 8)=="_balcadv" {;           local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"subs_balcadv"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _subs_balcadv, columns(`col') explicit; };
    if substr("`var'",-11,11)=="_balcadv_90" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"subs_balcadv_90"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _subs_balcadv_90, columns(`col') explicit; };
    if substr("`var'",-16,16)=="_tarfoutp_indexp" {;   local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"firm_indexp"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _firm_indexp, columns(`col') explicit; };
    if substr("`var'",-16,16)=="_tarfintm_indexp" {;   local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"firm_indexp"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _firm_indexp, columns(`col') explicit; };
    if substr("`var'",-15,15)=="_indexp_balcadv" {;    local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indexp_balcadv"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indexp_balcadv, columns(`col') explicit; };
    if substr("`var'",-18,18)=="_indexp_balcadv_90" {; local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indexp_balcadv_90"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indexp_balcadv_90, columns(`col') explicit; };
    if substr("`var'",-11,11)=="_notindprim" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"notindprim"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _notindprim, columns(`col') explicit; };
    if substr("`var'",- 9, 9)=="_indyoung" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indyoung"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indyoung, columns(`col') explicit; };
    if substr("`var'",- 9, 9)=="_indwhite" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indwhite"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indwhite, columns(`col') explicit; };
    if substr("`var'",- 9, 9)=="_indfemal" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = tradvars90[rownumb(tradvars90,"indfemal"),colnumb(tradvars90,"yr90_allsec")]; matname idmat_trad _indfemal, columns(`col') explicit; };
    if index("`var'","subs_tarfoutp_indexp_balcadv_90")>0  local tradvars "`tradvars' subs_tarfoutp";
    if index("`var'","subs_tarfoutp")>0 & index("`var'","subs_tarfoutp_indexp_balcadv_90")==0  local tradvars "`tradvars' subs_tarfoutp";
    if index("`var'","subs_tarfintm_indexp_balcadv_90")>0  local tradvars "`tradvars' subs_tarfintm";
    if index("`var'","subs_tarfintm")>0 & index("`var'","subs_tarfintm_indexp_balcadv_90")==0  local tradvars "`tradvars' subs_tarfintm";
    if index("`var'","subs_reffpen")>0   local tradvars "`tradvars' subs_reffpen";
    if index("`var'","firm_indexp")>0    local tradvars "`tradvars' firm_indexp";
    };
  matins tradvdif`yr'90, m(tarfvdifuse) ifr(`tradvars') over;
  mat predtarf`yr'90 = ( idmat_tarf * subs_hire )' * tarfvdifuse;
  };
# delimit cr
  
// report results
mat list subs_hire
mat list tradvdif9890
mat list predall9890
mat list predtrad9890
mat list predtarf9890
mat list tradvdif9490
mat list predall9490
mat list predtrad9490
mat list predtarf9490

// rename matrices to keep results
mat rename subs_hire subshire_coef_tbl
mat rename tradvars90 subshire_tradvars90_tbl
mat rename tradvars92 subshire_tradvars92_tbl
mat rename tradvars94 subshire_tradvars94_tbl
mat rename tradvars98 subshire_tradvars98_tbl


* SAVE MAIN MATRICES

foreach margin in dspl hire {
  foreach mat in _coef _tradvars90 _tradvars92 _tradvars94 _tradvars98 {
    mat rename subs`margin'`mat'_tbl subs`margin'`mat'_aerrr_tbl
    est2tex subs`margin'`mat'_aerrr, replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3)
    }
  }

log close


/* Matrix Use

predtrad
--------
subs_tarfoutp * 1
subs_tarfintm * 1
subs_reffpen * 1
firm_indexp * 1
subs_tarfoutp_indexp * firm_indexp
subs_tarfintm_indexp * firm_indexp
subs_tarfoutp_balcadv * subs_balcadv
subs_tarfintm_balcadv * subs_balcadv
subs_tarfoutp_indexp_balcadv * subs_balcadv
subs_tarfintm_indexp_balcadv * subs_balcadv
subs_tarfoutp_notindprim * notindprim
subs_tarfintm_notindprim * notindprim
subs_tarfoutp_indyoung * indyoung
subs_tarfintm_indyoung * indyoung
subs_tarfoutp_indwhite * indwhite
subs_tarfintm_indwhite * indwhite
subs_tarfoutp_indfemal * indfemal
subs_tarfintm_indfemal* indfemal

predtarf
--------
subs_tarfoutp * 1
subs_tarfintm * 1
subs_reffpen * 1
firm_indexp * 1
subs_tarfoutp_indexp * firm_indexp
subs_tarfintm_indexp * firm_indexp
subs_tarfoutp_balcadv * subs_balcadv
subs_tarfintm_balcadv * subs_balcadv
subs_tarfoutp_indexp_balcadv * firm_indexp * subs_balcadv
subs_tarfintm_indexp_balcadv * firm_indexp * subs_balcadv
subs_tarfoutp_notindprim * notindprim
subs_tarfintm_notindprim * notindprim
subs_tarfoutp_indyoung * indyoung
subs_tarfintm_indyoung * indyoung
subs_tarfoutp_indwhite * indwhite
subs_tarfintm_indwhite * indwhite
subs_tarfoutp_indfemal * indfemal
subs_tarfintm_indfemal* indfemal
*/
