version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl"

capture log close
log using "brazrloc/logs/separations-accessions-aer-natl-rr-cluster.log", replace

local maxiter $maxiter


// SUBSIBGE REGRESSIONS

local basendog "subs_tarfoutp subs_tarfintm firm_indexp"  // cut: subs_reffpen
local secexog  "subs_balcadv"
local secexo90 "subs_balcadv_90"
local secalt90 "subs_volrcadv_90"
local exoglst  "subs_secrealx subs_fdiflw subs_herfsale"
local cntrlfrm "plant_lnempl plant_indhigh plant_indcoll plant_indwhittot"
local ivlst    "subs_ppieu subs_ppinam imp_APD imp_CEE imp_NAM imp_ODV imp_OIN imp_WEU"
local intract1 "subs_tarfoutp_indexp subs_tarfintm_indexp"
local intract2 "subs_tarfoutp_balcadv subs_tarfintm_balcadv"
local intract3 "subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv"
local intract4 "subs_tarfoutp_notindprim subs_tarfintm_notindprim"  // if ~indprim
local intract5 "subs_tarfoutp_indyoung subs_tarfintm_indyoung"  // if potexper < 10
local intract6 "subs_tarfoutp_indwhite subs_tarfintm_indwhite"  // if indprof | indtech | indwhit
local addlreg  "subs_indprown_pis occ_indoutsrc"
local auxyr    "__brl_d population _ibx50d"

* SEPARATIONS NATL

local cntrlwrk "tenuryr potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/separations-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf indlayoff indquit
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }
gen byte subs_ibge = .
label var subs_ibge "Subsector IBGE"
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* regressions

xtreg inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(subs_ibge)
* est2vec subsdspl_berman, addto(subsdspl_berman) name(xt_secyrfe0_cluster)
* est2vec subsdspl_berman, raddto(subsdspl_berman) name(xt_secyrfe0_cluster)

xtreg inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid) cluster(subs_ibge)
* est2vec subsdspl_berman, addto(subsdspl_berman) name(xt_secyrtrdfe0_cluster)
* est2vec subsdspl_berman, raddto(subsdspl_berman) name(xt_secyrtrdfe0_cluster)


* ACCESSIONS NATL

local cntrlwrk "potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/accessions-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }
gen byte subs_ibge = .
label var subs_ibge "Subsector IBGE"
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* regressions

xtreg indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(subs_ibge)
* est2vec subshire_berman, addto(subshire_berman) name(xt_secyrfe0_cluster)
* est2vec subshire_berman, raddto(subshire_berman) name(xt_secyrfe0_cluster)

xtreg indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid)
* est2vec subshire_berman, addto(subshire_berman) name(xt_secyrtrdfe0_cluster)
* est2vec subshire_berman, raddto(subshire_berman) name(xt_secyrtrdfe0_cluster)

log close
