version 11.0
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl10pct"

capture log close
log using "brazrloc/logs/separations-accessions-aer-natl-rr-xt-cluster-10pct.log", replace

local maxiter $maxiter

capture program drop xtclstreg
program define xtclstreg, eclass
  syntax varlist [if] [in] [, FE I(varname) CLUSTER(varname)]
  tempname Vcluster Vi Vwhite Vrepost
  qui xtreg `varlist' `if' `in', fe i(`i') cluster(`cluster') nonest  // regression with `i'-fixed effects, clustering by `cluster'
  matrix `Vcluster' = e(V)
  qui xtreg `varlist' `if' `in', fe i(`i') cluster(`i')  // regression with `i'-fixed effects, clustering by i'
  matrix `Vi' = e(V)
  qui xtreg `varlist' `if' `in', fe i(`i') robust  // regression with `i'-fixed effects, robust standard errors
  matrix `Vwhite' = e(V)
  matrix `Vrepost' = `Vcluster' + `Vi' - `Vwhite'
  ereturn repost V = `Vrepost'
  * ereturn display
  xtreg
end

capture program drop ivreplc
program define ivreplc
  foreach reg in $regdef {
    replace imp_`reg' = imp_`reg' * ini_lnempl
    }
end

// AUXILIARY ANNUAL DATA

tempfile auxdat
insheet using "brazrloc/auxil/origs/pib.csv", clear
keep ano populacao pib_corrente_usd
rename ano year
label var year "Calendar Year"
rename populacao population
label var population "Population [mio]"
rename pib_corrente_usd gdp_usd
replace gdp_usd = gdp_usd/1000000
label var gdp_usd "GDP [current USD bio]"
keep if year>=1986 & year<=1998
sort year
merge year using "brazrloc/auxil/globfin-annual", nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m
keep year __brl_d population _ibx50d
sort year
save `auxdat'


// SUBSECTOR IBGE REGRESSIONS (CNAE and lower-level clustering)

local basendog "cnae_tarfoutp cnae_tarfintm firm_indexp"  // cut: cnae_reffpen
local secexog  "subs_balcadv"
local secexo90 "subs_balcadv_90"
local secalt90 "subs_volrcadv_90"
local exoglst  "cnae_secrealx cnae_fdiflw cnae_herfsale"
local cntrlfrm "plant_lnempl plant_indhigh plant_indcoll plant_indwhittot"
local ivlst    "cnae_ppieu cnae_ppinam imp_APD imp_CEE imp_NAM imp_OIN imp_WEU"
local intract1 "cnae_tarfoutp_indexp cnae_tarfintm_indexp"
local intract2 "cnae_tarfoutp_balcadv cnae_tarfintm_balcadv"
local intract2_90  "cnae_tarfoutp_balcadv_90 cnae_tarfintm_balcadv_90"
local intract3 "cnae_tarfoutp_indexp_balcadv cnae_tarfintm_indexp_balcadv"
local intract3_90  "cnae_tarfoutp_indexp_balcadv_90 cnae_tarfintm_indexp_balcadv_90"
local intract4 "cnae_tarfoutp_notindprim cnae_tarfintm_notindprim"  // if ~indprim
local intract5 "cnae_tarfoutp_indyoung cnae_tarfintm_indyoung"  // if potexper < 10
local intract6 "cnae_tarfoutp_indwhite cnae_tarfintm_indwhite"  // if indprof | indtech | indwhit
local intract7 "cnae_tarfoutp_indfemal cnae_tarfintm_indfemal"  // if indfemal
local intract8 "cnae_tarfoutp_notindprim cnae_tarfintm_notindprim firm_indexp_notindprim subs_balcadv_notindprim"
local intract9 "cnae_tarfoutp_indexp_notindprim cnae_tarfoutp_balcadv_notindprim cnae_tarfintm_indexp_notindprim cnae_tarfintm_balcadv_notindprim"
local addlreg  "cnae_indprown_pis occ_indoutsrc"
local auxyr    "__brl_d population _ibx50d"

* separations natl

local cntrlwrk "tenuryr tenuryr2 potexper potexper2 indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/separations-natl-subsibge-10pct.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf indlayoff indquit
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }
gen tenuryr2 = tenuryr * tenuryr
label var tenuryr2 "Squared Tenure at plant (sq. yrs.)"
gen potexper2 = potexper * potexper
label var potexper2 "Squared Pot. labor force exp."
order wid year cnpj_radic inddspl subs_balcadv subs_fdiflw subs_reffpen subs_tarfoutp subs_tarfintm subs_herfsale subs_indprown_pis occ_* plant_* firm_* tenuryr tenuryr2 potexper potexper2 indprim indhigh indscoll indgrad indprof indtech indwhit indsklb indunsklb indfemal subs_dollar subs_ppieu subs_ppinam subs_secrealx imp_* indyr_* indsubs_*

* merge additional sector information
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/sector-subsibge-data", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
count if _m~=3
if `r(N)'>0  STOP  // incomplete sector-year mapping
drop _m subs_fdistk subs_indunsklb

* update sector information with CNAE in 1994-2001 (563 industries), keep subsibge information for 1986-1993 (26 sectors)
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta", keep(mod_clas_cnae_95) nokeep
drop _m
rename ano year
rename mod_clas_cnae_95 cnae
replace cnae=. if cnae==-1 | cnae==0
replace cnae=int(cnae/10)
sort cnae year
merge cnae year using "brazrloc/auxil/sector-cnae-data.dta", nokeep  // CNAE sector information in 1994-2001
foreach var in secrealx fdiflw reffpen tarfoutp tarfintm herfsale indprown_pis indprown_pis_95 dollar ppieu ppinam {
  replace cnae_`var' = subs_`var' if year<=1993  // keep subsibge information for 1986-1993
  drop subs_`var'
  }
gen long cnaemix = cnae // CNAE sector information in 1994-2001
replace cnaemix = subs_ibge if year<=1993  // keep subsibge information for 1986-1993
drop _m
codebook subs_ibge cnae

* obtain sector information for niv50 when possible (PIA firms)
* sort cnpj_radic year
* merge cnpj_radic year using "brazrloc/data/pia-niv50.dta", nokeep
* tab _m
* count if niv50==. & firm_lnlp~=.
* count if niv50~=. & firm_lnlp==.
* drop _m
* codebook niv50

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain alternative revealed comparative-advantage measure
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge
rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* auxiliary annual data
sort year
merge year using `auxdat', nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv subs_volrcadv {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"

* interactions
gen cnae_tarfoutp_indexp = cnae_tarfoutp * firm_indexp
label var cnae_tarfoutp_indexp "tarfoutp * indexp"
gen cnae_tarfintm_indexp = cnae_tarfintm * firm_indexp
label var cnae_tarfintm_indexp "tarfintm * indexp"
gen cnae_tarfoutp_balcadv = cnae_tarfoutp * subs_balcadv
label var cnae_tarfoutp_balcadv "tarfoutp * balcadv"
gen cnae_tarfintm_balcadv = cnae_tarfintm * subs_balcadv
label var cnae_tarfintm_balcadv "tarfintm * balcadv"
gen cnae_tarfoutp_indexp_balcadv = cnae_tarfoutp * firm_indexp * subs_balcadv
label var cnae_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen cnae_tarfintm_indexp_balcadv = cnae_tarfintm * firm_indexp * subs_balcadv
label var cnae_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen cnae_tarfoutp_notindprim = cnae_tarfoutp * (~indprim) // if ~indprim
label var cnae_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen cnae_tarfintm_notindprim = cnae_tarfintm * (~indprim) // if ~indprim
label var cnae_tarfintm_notindprim "tarfintm * (~indprim)"
gen cnae_tarfoutp_indyoung = cnae_tarfoutp * (potexper<10) // if potexper < 10
label var cnae_tarfoutp_indyoung "cnae_tarfoutp * (potexper<10)"
gen cnae_tarfintm_indyoung = cnae_tarfintm * (potexper<10) // if potexper < 10
label var cnae_tarfintm_indyoung "cnae_tarfintm * (potexper<10)"
gen cnae_tarfoutp_indwhite = cnae_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var cnae_tarfoutp_indwhite "cnae_tarfoutp * (indwhit+)"
gen cnae_tarfintm_indwhite = cnae_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var cnae_tarfintm_indwhite "cnae_tarfintm * (indwhit+)"
gen cnae_tarfoutp_indfemal = cnae_tarfoutp * (indfemal) // if indfemal
label var cnae_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen cnae_tarfintm_indfemal = cnae_tarfintm * (indfemal) // if indfemal
label var cnae_tarfintm_indfemal "tarfintm * (indfemal)"
gen cnae_tarfoutp_balcadv_90 = cnae_tarfoutp * subs_balcadv_90
label var cnae_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen cnae_tarfintm_balcadv_90 = cnae_tarfintm * subs_balcadv_90
label var cnae_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen cnae_tarfoutp_indexp_balcadv_90 = cnae_tarfoutp * firm_indexp * subs_balcadv_90
label var cnae_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen cnae_tarfintm_indexp_balcadv_90 = cnae_tarfintm * firm_indexp * subs_balcadv_90
label var cnae_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"
gen cnae_tarfoutp_volrcadv_90 = cnae_tarfoutp * subs_volrcadv_90
label var cnae_tarfoutp_volrcadv_90 "tarfoutp * volrcadv_90"
gen cnae_tarfintm_volrcadv_90 = cnae_tarfintm * subs_volrcadv_90
label var cnae_tarfintm_volrcadv_90 "tarfintm * volrcadv_90"
gen cnae_tarfoutp_indexp_volrcadv_90 = cnae_tarfoutp * firm_indexp * subs_volrcadv_90
label var cnae_tarfoutp_indexp_volrcadv_90 "tarfoutp * indexp * volrcadv_90"
gen cnae_tarfintm_indexp_volrcadv_90 = cnae_tarfintm * firm_indexp * subs_volrcadv_90
label var cnae_tarfintm_indexp_volrcadv_90 "tarfintm * indexp * volrcadv_90"
gen subs_balcadv_up = subs_balcadv * (subs_balcadv >= subs_balcadv_90)
label var subs_balcadv_up "subs_balcadv if >= subs_balcadv_90"
gen subs_balcadv_dn = subs_balcadv * (subs_balcadv < subs_balcadv_90)
label var subs_balcadv_dn "subs_balcadv if < subs_balcadv_90"

* regressions

xtclstreg inddspl `basendog' `secexo90' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaedspl_aerrrxt, vars(cnae_tarfoutp cnae_tarfintm firm_indexp subs_balcadv subs_balcadv_90 subs_volrcadv_90 cnae_reffpen cnae_secrealx cnae_fdiflw cnae_herfsale plant_lnempl plant_indcoll plant_indhigh plant_indwhittot firm_lnlp tenuryr tenuryr2 potexper indprof indtech indwhit indsklb indunsklb cnae_tarfoutp_indexp cnae_tarfintm_indexp cnae_tarfoutp_balcadv cnae_tarfintm_balcadv cnae_tarfoutp_indexp_balcadv cnae_tarfintm_indexp_balcadv cnae_tarfoutp_notindprim cnae_tarfintm_notindprim cnae_tarfoutp_indyoung cnae_tarfintm_indyoung cnae_tarfoutp_indwhite cnae_tarfintm_indwhite cnae_tarfoutp_indfemal cnae_tarfintm_indfemal cnae_indprown_pis occ_indoutsrc cnae_dollar cnae_ppieu cnae_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 trd_indsubs_1 trd_indsubs_2 trd_indsubs_3 trd_indsubs_4 trd_indsubs_5 trd_indsubs_6 trd_indsubs_7 trd_indsubs_8 trd_indsubs_9 trd_indsubs_10 trd_indsubs_11 trd_indsubs_12 trd_indsubs_13 trd_indsubs_14 trd_indsubs_15 trd_indsubs_16 trd_indsubs_17 trd_indsubs_18 trd_indsubs_19 trd_indsubs_20 trd_indsubs_21 trd_indsubs_22 trd_indsubs_23 trd_indsubs_24 trd_indsubs_25 trd_indsubs_26) e(N ll chi2 p df_m r2 r2_p rc ic) name(xt_yrfe_exo90)
est2vec cnaedspl_aerrrxt, r(F p df df_r) name(xt_yrfe_exo90)

xtclstreg inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaedspl_aerrrxt, addto(cnaedspl_aerrrxt) name(xt_secyrfe0)
est2vec cnaedspl_aerrrxt, raddto(cnaedspl_aerrrxt) name(xt_secyrfe0)

codebook subs_ibge cnae if e(sample)

clogit inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnaedspl_aerrrxt, addto(cnaedspl_aerrrxt) name(clogit_secyrfe0)
est2vec cnaedspl_aerrrxt, raddto(cnaedspl_aerrrxt) name(clogit_secyrfe0)

xtclstreg inddspl firm_lnlp `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaedspl_aerrrxt, addto(cnaedspl_aerrrxt) name(xt_lnlp0)
est2vec cnaedspl_aerrrxt, raddto(cnaedspl_aerrrxt) name(xt_lnlp0)

xtclstreg inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaedspl_aerrrxt, addto(cnaedspl_aerrrxt) name(xt_secyrtrdfe0)
est2vec cnaedspl_aerrrxt, raddto(cnaedspl_aerrrxt) name(xt_secyrtrdfe0)

xtivreg inddspl `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec cnaedspl_aerrrxt, addto(cnaedspl_aerrrxt) name(xtiv_secyrfe0)
est2vec cnaedspl_aerrrxt, raddto(cnaedspl_aerrrxt) name(xtiv_secyrfe0)

xtclstreg inddspl `basendog' `intract1' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaedspl_aerrrxt, addto(cnaedspl_aerrrxt) name(xt_intract1)
est2vec cnaedspl_aerrrxt, raddto(cnaedspl_aerrrxt) name(xt_intract1)

xtclstreg inddspl `basendog' `intract2_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaedspl_aerrrxt, addto(cnaedspl_aerrrxt) name(xt_intract2)
est2vec cnaedspl_aerrrxt, raddto(cnaedspl_aerrrxt) name(xt_intract2)

xtclstreg inddspl `basendog' `intract1' `intract2_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaedspl_aerrrxt, addto(cnaedspl_aerrrxt) name(xt_intract12)
est2vec cnaedspl_aerrrxt, raddto(cnaedspl_aerrrxt) name(xt_intract12)

xtclstreg inddspl `basendog' `intract1' `intract2_90' `intract3_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaedspl_aerrrxt, addto(cnaedspl_aerrrxt) name(xt_intract3)
est2vec cnaedspl_aerrrxt, raddto(cnaedspl_aerrrxt) name(xt_intract3)

xtclstreg inddspl `basendog' `intract4' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaedspl_aerrrxt, addto(cnaedspl_aerrrxt) name(xt_intract4)
est2vec cnaedspl_aerrrxt, raddto(cnaedspl_aerrrxt) name(xt_intract4)

xtclstreg inddspl `basendog' `intract5' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaedspl_aerrrxt, addto(cnaedspl_aerrrxt) name(xt_intract5)
est2vec cnaedspl_aerrrxt, raddto(cnaedspl_aerrrxt) name(xt_intract5)

xtclstreg inddspl `basendog' `intract6' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaedspl_aerrrxt, addto(cnaedspl_aerrrxt) name(xt_intract6)
est2vec cnaedspl_aerrrxt, raddto(cnaedspl_aerrrxt) name(xt_intract6)


* accessions natl

local cntrlwrk "potexper potexper2 indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/accessions-natl-subsibge-10pct.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }
gen potexper2 = potexper * potexper
label var potexper2 "Squared Pot. labor force exp."
order wid year cnpj_radic indhire subs_balcadv subs_fdiflw subs_reffpen subs_tarfoutp subs_tarfintm subs_herfsale subs_indprown_pis occ_* plant_* firm_* potexper potexper2 indprim indhigh indscoll indgrad indprof indtech indwhit indsklb indunsklb indfemal subs_dollar subs_ppieu subs_ppinam subs_secrealx imp_* indyr_* indsubs_*

* merge additional sector information
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/sector-subsibge-data", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
count if _m~=3
if `r(N)'>0  STOP  // incomplete sector-year mapping
drop _m subs_fdistk subs_indunsklb

* update sector information with CNAE in 1994-2001 (563 industries), keep subsibge information for 1986-1993 (26 sectors)
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta", keep(mod_clas_cnae_95) nokeep
drop _m
rename ano year
rename mod_clas_cnae_95 cnae
replace cnae=. if cnae==-1 | cnae==0
replace cnae=int(cnae/10)
sort cnae year
merge cnae year using "brazrloc/auxil/sector-cnae-data.dta", nokeep  // CNAE sector information in 1994-2001
foreach var in secrealx fdiflw reffpen tarfoutp tarfintm herfsale indprown_pis indprown_pis_95 dollar ppieu ppinam {
  replace cnae_`var' = subs_`var' if year<=1993  // keep subsibge information for 1986-1993
  drop subs_`var'
  }
gen long cnaemix = cnae // CNAE sector information in 1994-2001
replace cnaemix = subs_ibge if year<=1993  // keep subsibge information for 1986-1993
drop _m
codebook subs_ibge cnae

* obtain sector information for niv50 when possible (PIA firms)
* sort cnpj_radic year
* merge cnpj_radic year using "brazrloc/data/pia-niv50.dta", nokeep
* tab _m
* count if niv50==. & firm_lnlp~=.
* count if niv50~=. & firm_lnlp==.
* drop _m
* codebook niv50

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain alternative revealed comparative-advantage measure
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge
rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* auxiliary annual data
sort year
merge year using `auxdat', nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv subs_volrcadv {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"

* interactions
gen cnae_tarfoutp_indexp = cnae_tarfoutp * firm_indexp
label var cnae_tarfoutp_indexp "tarfoutp * indexp"
gen cnae_tarfintm_indexp = cnae_tarfintm * firm_indexp
label var cnae_tarfintm_indexp "tarfintm * indexp"
gen cnae_tarfoutp_balcadv = cnae_tarfoutp * subs_balcadv
label var cnae_tarfoutp_balcadv "tarfoutp * balcadv"
gen cnae_tarfintm_balcadv = cnae_tarfintm * subs_balcadv
label var cnae_tarfintm_balcadv "tarfintm * balcadv"
gen cnae_tarfoutp_indexp_balcadv = cnae_tarfoutp * firm_indexp * subs_balcadv
label var cnae_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen cnae_tarfintm_indexp_balcadv = cnae_tarfintm * firm_indexp * subs_balcadv
label var cnae_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen cnae_tarfoutp_notindprim = cnae_tarfoutp * (~indprim) // if ~indprim
label var cnae_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen cnae_tarfintm_notindprim = cnae_tarfintm * (~indprim) // if ~indprim
label var cnae_tarfintm_notindprim "tarfintm * (~indprim)"
gen cnae_tarfoutp_indyoung = cnae_tarfoutp * (potexper<10) // if potexper < 10
label var cnae_tarfoutp_indyoung "cnae_tarfoutp * (potexper<10)"
gen cnae_tarfintm_indyoung = cnae_tarfintm * (potexper<10) // if potexper < 10
label var cnae_tarfintm_indyoung "cnae_tarfintm * (potexper<10)"
gen cnae_tarfoutp_indwhite = cnae_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var cnae_tarfoutp_indwhite "cnae_tarfoutp * (indwhit+)"
gen cnae_tarfintm_indwhite = cnae_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var cnae_tarfintm_indwhite "cnae_tarfintm * (indwhit+)"
gen cnae_tarfoutp_indfemal = cnae_tarfoutp * (indfemal) // if indfemal
label var cnae_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen cnae_tarfintm_indfemal = cnae_tarfintm * (indfemal) // if indfemal
label var cnae_tarfintm_indfemal "tarfintm * (indfemal)"
gen cnae_tarfoutp_balcadv_90 = cnae_tarfoutp * subs_balcadv_90
label var cnae_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen cnae_tarfintm_balcadv_90 = cnae_tarfintm * subs_balcadv_90
label var cnae_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen cnae_tarfoutp_indexp_balcadv_90 = cnae_tarfoutp * firm_indexp * subs_balcadv_90
label var cnae_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen cnae_tarfintm_indexp_balcadv_90 = cnae_tarfintm * firm_indexp * subs_balcadv_90
label var cnae_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"
gen cnae_tarfoutp_volrcadv_90 = cnae_tarfoutp * subs_volrcadv_90
label var cnae_tarfoutp_volrcadv_90 "tarfoutp * volrcadv_90"
gen cnae_tarfintm_volrcadv_90 = cnae_tarfintm * subs_volrcadv_90
label var cnae_tarfintm_volrcadv_90 "tarfintm * volrcadv_90"
gen cnae_tarfoutp_indexp_volrcadv_90 = cnae_tarfoutp * firm_indexp * subs_volrcadv_90
label var cnae_tarfoutp_indexp_volrcadv_90 "tarfoutp * indexp * volrcadv_90"
gen cnae_tarfintm_indexp_volrcadv_90 = cnae_tarfintm * firm_indexp * subs_volrcadv_90
label var cnae_tarfintm_indexp_volrcadv_90 "tarfintm * indexp * volrcadv_90"
gen subs_balcadv_up = subs_balcadv * (subs_balcadv >= subs_balcadv_90)
label var subs_balcadv_up "subs_balcadv if >= subs_balcadv_90"
gen subs_balcadv_dn = subs_balcadv * (subs_balcadv < subs_balcadv_90)
label var subs_balcadv_dn "subs_balcadv if < subs_balcadv_90"

* regressions

xtclstreg indhire `basendog' `secexo90' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaehire_aerrrxt, vars(cnae_tarfoutp cnae_tarfintm firm_indexp subs_balcadv subs_balcadv_90 subs_volrcadv_90 cnae_reffpen cnae_secrealx cnae_fdiflw cnae_herfsale plant_lnempl plant_indcoll plant_indhigh plant_indwhittot firm_lnlp tenuryr tenuryr2 potexper indprof indtech indwhit indsklb indunsklb cnae_tarfoutp_indexp cnae_tarfintm_indexp cnae_tarfoutp_balcadv cnae_tarfintm_balcadv cnae_tarfoutp_indexp_balcadv cnae_tarfintm_indexp_balcadv cnae_tarfoutp_notindprim cnae_tarfintm_notindprim cnae_tarfoutp_indyoung cnae_tarfintm_indyoung cnae_tarfoutp_indwhite cnae_tarfintm_indwhite cnae_tarfoutp_indfemal cnae_tarfintm_indfemal cnae_indprown_pis occ_indoutsrc cnae_dollar cnae_ppieu cnae_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 trd_indsubs_1 trd_indsubs_2 trd_indsubs_3 trd_indsubs_4 trd_indsubs_5 trd_indsubs_6 trd_indsubs_7 trd_indsubs_8 trd_indsubs_9 trd_indsubs_10 trd_indsubs_11 trd_indsubs_12 trd_indsubs_13 trd_indsubs_14 trd_indsubs_15 trd_indsubs_16 trd_indsubs_17 trd_indsubs_18 trd_indsubs_19 trd_indsubs_20 trd_indsubs_21 trd_indsubs_22 trd_indsubs_23 trd_indsubs_24 trd_indsubs_25 trd_indsubs_26) e(N ll chi2 p df_m r2 r2_p rc ic) name(xt_yrfe_exo90)
est2vec cnaehire_aerrrxt, r(F p df df_r) name(xt_yrfe_exo90)

xtclstreg indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaehire_aerrrxt, addto(cnaehire_aerrrxt) name(xt_secyrfe0)
est2vec cnaehire_aerrrxt, raddto(cnaehire_aerrrxt) name(xt_secyrfe0)

codebook subs_ibge cnae if e(sample)

clogit indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec cnaehire_aerrrxt, addto(cnaehire_aerrrxt) name(clogit_secyrfe0)
est2vec cnaehire_aerrrxt, raddto(cnaehire_aerrrxt) name(clogit_secyrfe0)

xtclstreg indhire firm_lnlp `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaehire_aerrrxt, addto(cnaehire_aerrrxt) name(xt_lnlp0)
est2vec cnaehire_aerrrxt, raddto(cnaehire_aerrrxt) name(xt_lnlp0)

xtclstreg indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaehire_aerrrxt, addto(cnaehire_aerrrxt) name(xt_secyrtrdfe0)
est2vec cnaehire_aerrrxt, raddto(cnaehire_aerrrxt) name(xt_secyrtrdfe0)

xtivreg indhire `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec cnaehire_aerrrxt, addto(cnaehire_aerrrxt) name(xtiv_secyrfe0)
est2vec cnaehire_aerrrxt, raddto(cnaehire_aerrrxt) name(xtiv_secyrfe0)

xtclstreg indhire `basendog' `intract1' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaehire_aerrrxt, addto(cnaehire_aerrrxt) name(xt_intract1)
est2vec cnaehire_aerrrxt, raddto(cnaehire_aerrrxt) name(xt_intract1)

xtclstreg indhire `basendog' `intract2_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaehire_aerrrxt, addto(cnaehire_aerrrxt) name(xt_intract2)
est2vec cnaehire_aerrrxt, raddto(cnaehire_aerrrxt) name(xt_intract2)

xtclstreg indhire `basendog' `intract1' `intract2_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaehire_aerrrxt, addto(cnaehire_aerrrxt) name(xt_intract12)
est2vec cnaehire_aerrrxt, raddto(cnaehire_aerrrxt) name(xt_intract12)

xtclstreg indhire `basendog' `intract1' `intract2_90' `intract3_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaehire_aerrrxt, addto(cnaehire_aerrrxt) name(xt_intract3)
est2vec cnaehire_aerrrxt, raddto(cnaehire_aerrrxt) name(xt_intract3)

xtclstreg indhire `basendog' `intract4' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaehire_aerrrxt, addto(cnaehire_aerrrxt) name(xt_intract4)
est2vec cnaehire_aerrrxt, raddto(cnaehire_aerrrxt) name(xt_intract4)

xtclstreg indhire `basendog' `intract5' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaehire_aerrrxt, addto(cnaehire_aerrrxt) name(xt_intract5)
est2vec cnaehire_aerrrxt, raddto(cnaehire_aerrrxt) name(xt_intract5)

xtclstreg indhire `basendog' `intract6' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(cnaemix)
est2vec cnaehire_aerrrxt, addto(cnaehire_aerrrxt) name(xt_intract6)
est2vec cnaehire_aerrrxt, raddto(cnaehire_aerrrxt) name(xt_intract6)


// Save results

foreach type in b se e r {
  matsave cnaedspl_aerrrxt_`type', p(brazrloc/estmat/v4/reg/natl10pct) t(double) replace dropall
  matsave cnaehire_aerrrxt_`type', p(brazrloc/estmat/v4/reg/natl10pct) t(double) replace dropall
  }

log close
