version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl-maleprime"

capture log close
log using "brazrloc/logs/separations-accessions-natl-maleprime-cnae-cluster.log", replace

local maxiter $maxiter

local focallst "cnae_balcadv firm_indexp"
local addlst   "cnae_balcadv_tarf firm_indexp_tarf cnae_balcadv_indexp cnae_balcadv_indexp_tarf"
local cntrlfrm "cnae_secrealx cnae_fdiflw cnae_herfsale plant_lnempl plant_indprim plant_indhigh plant_indwhittot"
local addlwrkr "indhigh indscoll indgrad" 
local endog    "cnae_tarfoutp cnae_tarfintm cnae_reffpen"
local baseiv   "cnae_dollar cnae_ppieu cnae_ppinam"
local expiv    "imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU"


* SUBSECTOR IBGE VARIABLES, BRAZILIAN PRIME-AGE MALES
*----------------------------------------------------

* SEPARATION REGRESSIONS WITH CLUSTERING AT SECTOR LEVEL

local cntrlwrk "tenuryr potexper indprof indtech indwhit indsklb"
use "brazrloc/data/separations-natl-maleprime-cnae.dta", clear

// obtain sector IDs from dummies
gen byte subs_ibge = .
label var subs_ibge "Subsector IBGE"
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge

// keep only last separation per year
drop if indexcl

// xt comparison regressions

xtreg inddspl `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, fe i(wid) cluster(subs_ibge)
* est2vec cnae_berman, addto(cnae_berman) name(xtreg_cluster_subs)

xtreg inddspl `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* indsubs* if year>=1990, fe i(wid) cluster(subs_ibge)
* est2vec cnae_berman, addto(cnae_berman) name(xtreg_cluster_subsfe)


* ACCESSION REGRESSIONS WITH CLUSTERING AT SECTOR LEVEL

local cntrlwrk "indprof indtech indwhit indsklb"
use "brazrloc/data/accessions-natl-maleprime-cnae.dta", clear

// obtain sector IDs from dummies
gen byte subs_ibge = .
label var subs_ibge "Subsector IBGE"
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge

// keep only first accession per year
drop if indexcl

// xt comparison regressions

xtreg indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, fe i(wid) cluster(subs_ibge)
* est2vec cnae_berman, addto(cnae_berman) name(xtreg_cluster_subs)

xtreg indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* indsubs* if year>=1990, fe i(wid) cluster(subs_ibge)
* est2vec cnae_berman, addto(cnae_berman) name(xtreg_cluster_subsfe)

log close

