version 8.2
clear
set more off
set matsize 200

capture mkdir "brazrloc/tex/v4/ext"
capture mkdir "brazrloc/tex/v4/ext/reg"

* Load variable names and save for est2tex
est2extlbl, addto(compadv) intex($root/brazrloc/%stata/rowlbl-brazrloc) p(brazrloc/tex/v4/ext/reg) replace
est2extlbl, addto(compadvreg) retain p(brazrloc/tex/v4/ext/reg) replace
est2extlbl, addto(expadv) retain p(brazrloc/tex/v4/ext/reg) replace
est2extlbl, addto(expadvreg) retain p(brazrloc/tex/v4/ext/reg) replace
est2extlbl, addto(balcadv) retain p(brazrloc/tex/v4/ext/reg) replace
est2extlbl, addto(balcadvreg) retain p(brazrloc/tex/v4/ext/reg) replace
est2extlbl, addto(rigidity) retain p(brazrloc/tex/v4/ext/reg) replace
clear


/* LOAD MATRICES */

foreach advtype in comp exp balc {
  foreach type in b se e r {
    drop _all
    matload `advtype'pol_`type', p(brazrloc/estmat/v4/ext) over missing(.)
    drop _all
    matload `advtype'advreg_`type', p(brazrloc/estmat/v4/ext) over missing(.)
    matorder `advtype'advreg_`type', matrix(`advtype'advreg_`type') ifcol(xtallyrs xtyrs90_98 regallyrs regyrs90_98) over
    }
  }
matload rigidity, p(brazaux/intl) over missing(.)


/* PREPARE TABLES */

foreach advtype in comp exp balc {

* Comparative Advantage Table from Joint Regressions
est2tex `advtype'advreg, fancy p(brazrloc/tex/v4/ext/reg) replace level(90 95 99) mark(starse) dropall extracols(2)

* Comparative Advantage Table from Individual Policy Regressions
foreach period in allyrs 1986 1990 1994 1997 {
  foreach type in b se e {
    matorder `advtype'pol_`type', matrix(`advtype'pol_`period'_`type') ifcol(erp_`period' tarfoutp_`period' tarfintm_`period') over
    }
  matrix roweq `advtype'pol_`period'_b  = `period' `period'
  matrix roweq `advtype'pol_`period'_se = `period' `period'
  matrix roweq `advtype'pol_`period'_e  = `period' `period' `period'
  }
foreach type in b se e {
  mat `advtype'adv_`type' = `advtype'pol_allyrs_`type' \ `advtype'pol_1986_`type' \ `advtype'pol_1990_`type' \ `advtype'pol_1994_`type' \ `advtype'pol_1997_`type'
  mat drop `advtype'pol_allyrs_`type' `advtype'pol_1986_`type' `advtype'pol_1990_`type' `advtype'pol_1994_`type' `advtype'pol_1997_`type'
  }
est2tex `advtype'adv, fancy p(brazrloc/tex/v4/ext/reg) replace level(90 95 99) mark(starse) dropall

* Clean Up
foreach type in b se e tbl {
  capture mat drop `advtype'pol_`type' 
  capture mat drop `advtype'adv_`type'
  }

} /* close `advtype' loop */


* Rigidity Table
mat rename rigidity rigidity_tbl
est2tex rigidity, ready fancy p(brazrloc/tex/v4/labor) replace dropall digits(1)
mat drop rigidity_tbl
