version 8.2
clear
set more off
set matsize 200

capture mkdir "brazrloc/tex/v4/gdp"

capture log close
log using "brazrloc/logs/gdp-impact-aer.log", replace

capture program drop rowlbl
program define rowlbl
  args mat neweq
  local rownames : rowfullnames `mat'
  local rows : word count `rownames'
  local rownewnames ""
  tokenize `rownames'
  forvalues i = 1/`rows' {
    local ipls1 = `i' + 1
    * disp "``i''"
    if index("``i''",":r(mean)")>0  local `i' = "`neweq':" + substr("``i''",1,index("``i''",":")-1)
    local rownewnames "`rownewnames' ``i''"
    }
  mat rownames `mat' = `rownewnames'
end

capture program drop complist
program define complist
  args margin
  qui svmat subs`margin'_meff, names(col)
  qui gen str idmatnames = ""
  qui gen str meanvar90 = "" 
  qui gen str tradvdifuse = ""
  keep idmatnames meanvar90 tradvdifuse
  local rows = rowsof(idmat_trad)
  local idmatnames : rownames idmat_trad
  tokenize `idmatnames'
  forvalues i = 1/`rows' {
    qui replace idmatnames = "``i''" in `i'
    }
  local meanvar90 : colnames idmat_trad
  tokenize `meanvar90'
  forvalues i = 1/`rows' {
    qui replace meanvar90 = "``i''" in `i'
    qui replace meanvar90 = "1" if substr(meanvar90,1,1)~="_" & substr(meanvar90,1,1)~="0"
    }
  local tradvdif : rownames tradvdifuse
  tokenize `tradvdif'
  forvalues i = 1/`rows' {
    qui replace tradvdifuse = "``i''" in `i'
    }
  list idmatnames meanvar90 tradvdifuse
  drop idmatnames meanvar90 tradvdifuse
end


/* REALLOCATION DURATIONS AND FAILURES BY SKILL GROUP */

matload mo2rehr12mbygrp_tbl, p(brazrloc/tex/v4/natl/duration) dropall missing(.) over
matorder mo2rehr12mbygrp_tbl, m(_rlocsucc_aer_tbl) ifc(mo2rehir1986 mo2rehir1990 mo2rehir1992 mo2rehir1994 mo2rehir1998)
mat _rlocsucc_aer_tbl = _rlocsucc_aer_tbl[1..6,1...] \ _rlocsucc_aer_tbl[9..10,1...]  \ _rlocsucc_aer_tbl[13..16,1...]
rowlbl _rlocsucc_aer_tbl  mo2rehr
matload indnorloc12mbygrp_tbl, p(brazrloc/tex/v4/natl/duration) dropall missing(.) over
matorder indnorloc12mbygrp_tbl, m(rlocsucc_aer_tbl) ifc(indnorloc1986 indnorloc1990 indnorloc1992 indnorloc1994 indnorloc1998)
rowlbl rlocsucc_aer_tbl indnorloc
mat rlocsucc_aer_tbl = rlocsucc_aer_tbl[1..6,1...] \ rlocsucc_aer_tbl[9..10,1...]  \ rlocsucc_aer_tbl[13..18,1...]
mat rlocsucc_aer_tbl = _rlocsucc_aer_tbl \ rlocsucc_aer_tbl
mat drop indnorloc12mbygrp_tbl mo2rehr12mbygrp_tbl _rlocsucc_aer_tbl
mat colnames rlocsucc_aer_tbl = y1986 y1990 y1992 y1994 y1998
foreach yr in 86 90 92 94 98 {  // from 1% random sample to population numbers
  mat rlocsucc_aer_tbl[rownumb(rlocsucc_aer_tbl,"any:r(N)"),colnumb(rlocsucc_aer_tbl,"y19`yr'")] = rlocsucc_aer_tbl[rownumb(rlocsucc_aer_tbl,"any:r(N)"),colnumb(rlocsucc_aer_tbl,"y19`yr'")]*100
  }
est2tex rlocsucc_aer, replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3) level(90 95 99) mark(starse)


/* LOAD MATRICES */

matload indnorloc12mbygrp_tbl, p(brazrloc/tex/v4/natl/duration) dropall missing(.) over
matload mo2rehr12mbygrp_tbl, p(brazrloc/tex/v4/natl/duration) dropall missing(.) over
matorder indnorloc12mbygrp_tbl, m(multsal_indnorloc) ifr(any:mean_rem_media)
mat multsal_indnorloc = multsal_indnorloc '
matrix coleq multsal_indnorloc = indnorloc
matorder mo2rehr12mbygrp_tbl, m(multsal_mo2rehr) ifr(any:mean_rem_media)
mat multsal_mo2rehr = multsal_mo2rehr '
matrix coleq multsal_mo2rehr = mo2rehr
mat multsal_comp = multsal_indnorloc , multsal_mo2rehr
mat list multsal_comp
mat drop multsal_comp multsal_mo2rehr


/* TRADE-RELATED PREDICTIONS OF SEPARATION AND ACCESSION RATE CHANGES */

* Labor-market effects of trade changes: (1-phat)*phat * _coef * mean_exvar * Delta`yr' var
* (1-phat)*phat: from subs`margin'_coef_aerrr_tbl (%3/prediction-stats-aerrr-natl.do, originally from subsdspl_aerrr_intract_b from %3/separations-accessions-aer-natl-rr-intract.do)
* _coef: from subs`margin'_coef_aerrr_tbl (%3/prediction-stats-aerrr-natl.do)
* mean_exvar: from subs`margin'_tradvars90_aerrr_tbl (%3/prediction-stats-aerrr-natl.do)
* Delta`yr' var: from subs`margin'_tradvars`yr'_aerrr_tbl less subs`margin'_tradvars90_aerrr_tbl (%3/prediction-stats-aerrr-natl.do)

foreach margin in dspl hire {
  foreach mat in _tradvars90 _tradvars92 _tradvars94 _tradvars98 {
    matload subs`margin'`mat'_aerrr_tbl, dropall p(brazrloc/tex/v4/gdp) over missing(.)
    local rownames : rownames subs`margin'`mat'_aerrr_tbl  
    }
  matload subs`margin'_aerrr_b, p(brazrloc/estmat/v4/reg/natl) over dropall missing(.)
  matins subs`margin'_aerrr_b, m(subs_`margin') ifr(subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp subs_tarfoutp_indexp subs_tarfintm_indexp subs_tarfoutp_balcadv subs_tarfoutp_balcadv_90 subs_tarfintm_balcadv subs_tarfintm_balcadv_90 subs_tarfoutp_indexp_balcadv subs_tarfoutp_indexp_balcadv_90 subs_tarfintm_indexp_balcadv subs_tarfintm_indexp_balcadv_90 subs_tarfoutp_notindprim subs_tarfintm_notindprim subs_tarfoutp_indyoung subs_tarfintm_indyoung subs_tarfoutp_indwhite subs_tarfintm_indwhite subs_tarfoutp_indfemal subs_tarfintm_indfemal) over
  matorder subs_`margin', m(subs_`margin') ifc(clogit_secyrfe0 clogit_secyrfe clogit_nofe clogit_secfe_auxyr xt_secyrfe0 xtiv_secyrfe0) over
  mat drop subs`margin'_aerrr_b
  matload subs`margin'_aerrr_intract_b, p(brazrloc/estmat/v4/reg/natl) over dropall missing(.)
  matins subs`margin'_aerrr_intract_b, m(subs_`margin'_intr) ifr(subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp subs_tarfoutp_indexp subs_tarfintm_indexp subs_tarfoutp_balcadv subs_tarfoutp_balcadv_90 subs_tarfintm_balcadv subs_tarfintm_balcadv_90 subs_tarfoutp_indexp_balcadv subs_tarfoutp_indexp_balcadv_90 subs_tarfintm_indexp_balcadv subs_tarfintm_indexp_balcadv_90 subs_tarfoutp_notindprim subs_tarfintm_notindprim subs_tarfoutp_indyoung subs_tarfintm_indyoung subs_tarfoutp_indwhite subs_tarfintm_indwhite subs_tarfoutp_indfemal subs_tarfintm_indfemal) over
  matorder subs_`margin'_intr, m(subs_`margin'_intr) ifc(clogit_intract3 clogit_intract3_reffpen clogit_intract30_90 clogit_intract30_90_reffpen clogit_intract70) over
  mat subs_`margin' = subs_`margin' , subs_`margin'_intr
  mat drop subs`margin'_aerrr_intract_b subs_`margin'_intr
  local rows = rowsof(subs_`margin')
  local cols = colsof(subs_`margin')
  forvalues i = 1/`rows' {
    forvalues j = 1/`cols' {
      if subs_`margin'[`i',`j']==.  mat subs_`margin'[`i',`j']=0
      }
    }
  mat rename subs_`margin' subs`margin'_coef_aerrr_tbl
  }

# delimit ;
foreach margin in dspl hire {;
  // meff: marginal effect of variables on dspl and hire: phat*(1-phat) * _coef;
  local phatsecyr`margin' = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"phatsecyr"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")];
  local phatyr`margin' = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"phatyr"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")];
  local phatitr3`margin' = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"phatitr3"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")];
  local phatitr7`margin' = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"phatitr7"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")];
  disp in gr "Estimated phatsecyr*(1-phatsecyr) at " in ye "`margin'" in gr " margin: " in ye %9.3f `phatsecyr`margin'' * (1-`phatsecyr`margin'');
  disp in gr "Estimated phatyr*(1-phatyr) at " in ye "`margin'" in gr " margin: " in ye %9.3f `phatyr`margin'' * (1-`phatyr`margin'');
  disp in gr "Estimated phatitr3*(1-phatitr3) at " in ye "`margin'" in gr " margin: " in ye %9.3f `phatitr3`margin'' * (1-`phatitr3`margin'');
  disp in gr "Estimated phatitr7*(1-phatitr7) at " in ye "`margin'" in gr " margin: " in ye %9.3f `phatitr7`margin'' * (1-`phatitr7`margin'');
  matorder subs`margin'_coef_aerrr_tbl, m(subs`margin'_coef_aerrr_tbl) ifc(clogit_secyrfe0 clogit_secyrfe clogit_nofe clogit_secfe_auxyr xt_secyrfe0 xtiv_secyrfe0 clogit_intract3 clogit_intract3_reffpen clogit_intract30_90 clogit_intract30_90_reffpen clogit_intract70) over;
  mat subs`margin'_meff = subs`margin'_coef_aerrr_tbl;
  local colnames : colnames subs`margin'_meff;
  local rows = rowsof(subs`margin'_meff);
  foreach spec of local colnames {;
    forvalues i = 1/`rows' {;
      if substr("`spec'",1,10)=="clogit_sec"   mat subs`margin'_meff[`i',colnumb(subs`margin'_meff,"`spec'")] = `phatsecyr`margin'' * (1-`phatsecyr`margin'') * subs`margin'_meff[`i',colnumb(subs`margin'_meff,"`spec'")];
      if substr("`spec'",1,11)=="clogit_nofe"  mat subs`margin'_meff[`i',colnumb(subs`margin'_meff,"`spec'")] = `phatyr`margin'' * (1-`phatyr`margin'') * subs`margin'_meff[`i',colnumb(subs`margin'_meff,"`spec'")];
      if "`spec'"=="clogit_intract30_90" | "`spec'"=="clogit_intract3" | "`spec'"=="clogit_intract30_90_reffpen"  mat subs`margin'_meff[`i',colnumb(subs`margin'_meff,"`spec'")] = `phatitr3`margin'' * (1-`phatitr3`margin'') * subs`margin'_meff[`i',colnumb(subs`margin'_meff,"`spec'")];
      if "`spec'"=="clogit_intract70"  mat subs`margin'_meff[`i',colnumb(subs`margin'_meff,"`spec'")] = `phatitr7`margin'' * (1-`phatitr7`margin'') * subs`margin'_meff[`i',colnumb(subs`margin'_meff,"`spec'")];
      };
    };
  * mat drop subs`margin'_coef_aerrr_tbl;
  // predtrad: allow export status (indexp) and effective penetration (reffpen) to vary alongside tariffs;
  foreach yr in 92 94 98 {;
    disp; disp in gr "margin " in ye "`margin'" in gr "; prediction for " in ye "`yr'90";
    mat tradvdif`yr'90 = subs`margin'_tradvars`yr'_aerrr_tbl - subs`margin'_tradvars90_aerrr_tbl;
    mat idmat_trad = I(`rows');
    local rownames : rownames subs`margin'_meff;
    mat rownames idmat_trad = `rownames';
    mat colnames idmat_trad = `rownames';
    local tradvars "";
    foreach var of local rownames {;
      local col "-";
      if substr("`var'",- 8, 8)=="_balcadv" {;           local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv, columns(`col') explicit; };
      if substr("`var'",-11,11)=="_balcadv_90" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_90"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv_90, columns(`col') explicit; };
      if substr("`var'",-15,15)=="_indexp_balcadv" {;    local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv, columns(`col') explicit; };
      if substr("`var'",-18,18)=="_indexp_balcadv_90" {; local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_90"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv_90, columns(`col') explicit; };
      if substr("`var'",-11,11)=="_notindprim" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"notindprim"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _notindprim, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indyoung" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indyoung"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indyoung, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indwhite" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indwhite"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indwhite, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indfemal" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indfemal"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indfemal, columns(`col') explicit; };
      disp in ye "`col': `var'";
      if index("`var'","subs_tarfoutp_indexp")>0  local tradvars "`tradvars' subs_tarfoutp_indexp";
      if index("`var'","subs_tarfoutp")>0 & index("`var'","subs_tarfoutp_indexp")==0  local tradvars "`tradvars' subs_tarfoutp";
      if index("`var'","subs_tarfintm_indexp")>0  local tradvars "`tradvars' subs_tarfintm_indexp";
      if index("`var'","subs_tarfintm")>0 & index("`var'","subs_tarfintm_indexp")==0  local tradvars "`tradvars' subs_tarfintm";
      if index("`var'","subs_reffpen")>0   local tradvars "`tradvars' subs_reffpen";
      if index("`var'","firm_indexp")>0    local tradvars "`tradvars' firm_indexp";
      };
    matins tradvdif`yr'90, m(tradvdifuse) ifr(`tradvars') over;
    mat predtrad`yr'90 = ( idmat_trad * subs`margin'_meff )' * tradvdifuse;
    mat roweq predtrad`yr'90 = `margin'_predtrad;
    * check computation;
    complist `margin';
    };
  // predtarf: fix export status (indexp) at sample mean;
  foreach yr in 92 94 98 {;
    disp; disp in gr "margin " in ye "`margin'" in gr "; prediction for " in ye "`yr'90";
    mat tradvdif`yr'90 = subs`margin'_tradvars`yr'_aerrr_tbl - subs`margin'_tradvars90_aerrr_tbl;
    mat idmat_trad = I(`rows');
    local rownames : rownames subs`margin'_meff;
    mat rownames idmat_trad = `rownames';
    mat colnames idmat_trad = `rownames';
    local tradvars "";
    foreach var of local rownames {;
      local col "-";
      if substr("`var'",-11,11)=="firm_indexp" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = 0; matname idmat_trad 0, columns(`col') explicit; };
      if substr("`var'",- 8, 8)=="_balcadv" {;           local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv, columns(`col') explicit; };
      if substr("`var'",-11,11)=="_balcadv_90" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_90"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv_90, columns(`col') explicit; };
      if substr("`var'",-16,16)=="_tarfoutp_indexp" {;   local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"firm_indexp"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _firm_indexp, columns(`col') explicit; };
      if substr("`var'",-16,16)=="_tarfintm_indexp" {;   local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"firm_indexp"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _firm_indexp, columns(`col') explicit; };
      if substr("`var'",-15,15)=="_indexp_balcadv" {;    local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indexp_balcadv"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indexp_balcadv, columns(`col') explicit; };
      if substr("`var'",-18,18)=="_indexp_balcadv_90" {; local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indexp_balcadv_90"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indexp_balcadv_90, columns(`col') explicit; };
      if substr("`var'",-11,11)=="_notindprim" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"notindprim"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _notindprim, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indyoung" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indyoung"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indyoung, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indwhite" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indwhite"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indwhite, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indfemal" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indfemal"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indfemal, columns(`col') explicit; };
      disp in ye "`col': `var'";
      if index("`var'","subs_tarfoutp_indexp_balcadv_90")>0  local tradvars "`tradvars' subs_tarfoutp";
      if index("`var'","subs_tarfoutp")>0 & index("`var'","subs_tarfoutp_indexp_balcadv_90")==0  local tradvars "`tradvars' subs_tarfoutp";
      if index("`var'","subs_tarfintm_indexp_balcadv_90")>0  local tradvars "`tradvars' subs_tarfintm";
      if index("`var'","subs_tarfintm")>0 & index("`var'","subs_tarfintm_indexp_balcadv_90")==0  local tradvars "`tradvars' subs_tarfintm";
      if index("`var'","subs_reffpen")>0   local tradvars "`tradvars' subs_reffpen";
      if index("`var'","firm_indexp")>0    local tradvars "`tradvars' firm_indexp";
      };
    matins tradvdif`yr'90, m(tradvdifuse) ifr(`tradvars') over;
    mat predtarf`yr'90 = ( idmat_trad * subs`margin'_meff )' * tradvdifuse;
    mat roweq predtarf`yr'90 = `margin'_predtarf;
    * check computation;
    complist `margin';
    };
  // predtarfexp: effects at exporters (indexp==1), allow effective penetration (reffpen) to vary alongside tariffs;
  foreach yr in 92 94 98 {;
    disp; disp in gr "margin " in ye "`margin'" in gr "; prediction for " in ye "`yr'90";
    mat tradvdif`yr'90 = subs`margin'_tradvars`yr'_aerrr_tbl - subs`margin'_tradvars90_aerrr_tbl;
    mat idmat_trad = I(`rows');
    local rownames : rownames subs`margin'_meff;
    mat rownames idmat_trad = `rownames';
    mat colnames idmat_trad = `rownames';
    local tradvars "";
    foreach var of local rownames {;
      local col "-";
      if substr("`var'",-11,11)=="firm_indexp" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = 0; matname idmat_trad 0, columns(`col') explicit; };
      if substr("`var'",- 8, 8)=="_balcadv" {;           local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv, columns(`col') explicit; };
      if substr("`var'",-11,11)=="_balcadv_90" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_90"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv_90, columns(`col') explicit; };
      if substr("`var'",-15,15)=="_indexp_balcadv" {;    local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv, columns(`col') explicit; };
      if substr("`var'",-18,18)=="_indexp_balcadv_90" {; local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_90"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv_90, columns(`col') explicit; };
      if substr("`var'",-11,11)=="_notindprim" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"notindprim"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _notindprim, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indyoung" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indyoung"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indyoung, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indwhite" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indwhite"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indwhite, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indfemal" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indfemal"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indfemal, columns(`col') explicit; };
      disp in ye "`col': `var'";
      if index("`var'","subs_tarfoutp_indexp")>0  local tradvars "`tradvars' subs_tarfoutp";
      if index("`var'","subs_tarfoutp")>0 & index("`var'","subs_tarfoutp_indexp")==0  local tradvars "`tradvars' subs_tarfoutp";
      if index("`var'","subs_tarfintm_indexp")>0  local tradvars "`tradvars' subs_tarfintm";
      if index("`var'","subs_tarfintm")>0 & index("`var'","subs_tarfintm_indexp")==0  local tradvars "`tradvars' subs_tarfintm";
      if index("`var'","subs_reffpen")>0   local tradvars "`tradvars' subs_reffpen";
      if index("`var'","firm_indexp")>0    local tradvars "`tradvars' firm_indexp";
      };
    matins tradvdif`yr'90, m(tradvdifuse) ifr(`tradvars') over;
    mat predtarfexp`yr'90 = ( idmat_trad * subs`margin'_meff )' * tradvdifuse;
    mat predtarfexp`yr'90 = predtarfexp`yr'90[1...,colnumb(predtarfexp`yr'90,"yr90_allsec")];
    mat colnames predtarfexp`yr'90 = yr90_indexp;
    mat roweq predtarfexp`yr'90 = `margin'_predtarfexp;
    * check computation;
    complist `margin';
    };
  // predtradq5: effects within top-compadv quartile, allow export status (indexp) and effective penetration (reffpen) to vary alongside tariffs;
  foreach yr in 92 94 98 {;
    disp; disp in gr "margin " in ye "`margin'" in gr "; prediction for " in ye "`yr'90";
    mat tradvdif`yr'90 = subs`margin'_tradvars`yr'_aerrr_tbl - subs`margin'_tradvars90_aerrr_tbl;
    mat idmat_trad = I(`rows');
    local rownames : rownames subs`margin'_meff;
    mat rownames idmat_trad = `rownames';
    mat colnames idmat_trad = `rownames';
    local tradvars "";
    foreach var of local rownames {;
      local col "-";
      if substr("`var'",- 8, 8)=="_balcadv" {;           local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_q5"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv_q5, columns(`col') explicit; };
      if substr("`var'",-11,11)=="_balcadv_90" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_q5"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv_q5, columns(`col') explicit; };
      if substr("`var'",-15,15)=="_indexp_balcadv" {;    local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_q5"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv_q5, columns(`col') explicit; };
      if substr("`var'",-18,18)=="_indexp_balcadv_90" {; local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_q5"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv_q5, columns(`col') explicit; };
      if substr("`var'",-11,11)=="_notindprim" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"notindprim"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _notindprim, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indyoung" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indyoung"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indyoung, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indwhite" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indwhite"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indwhite, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indfemal" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indfemal"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indfemal, columns(`col') explicit; };
      disp in ye "`col': `var'";
      if index("`var'","subs_tarfoutp_indexp")>0  local tradvars "`tradvars' subs_tarfoutp_indexp";
      if index("`var'","subs_tarfoutp")>0 & index("`var'","subs_tarfoutp_indexp")==0  local tradvars "`tradvars' subs_tarfoutp";
      if index("`var'","subs_tarfintm_indexp")>0  local tradvars "`tradvars' subs_tarfintm_indexp";
      if index("`var'","subs_tarfintm")>0 & index("`var'","subs_tarfintm_indexp")==0  local tradvars "`tradvars' subs_tarfintm";
      if index("`var'","subs_reffpen")>0   local tradvars "`tradvars' subs_reffpen";
      if index("`var'","firm_indexp")>0    local tradvars "`tradvars' firm_indexp";
      };
    matins tradvdif`yr'90, m(tradvdifuse) ifr(`tradvars') over;
    mat predtradq5`yr'90 = ( idmat_trad * subs`margin'_meff )' * tradvdifuse;
    mat predtradq5`yr'90 = predtradq5`yr'90[1...,colnumb(predtradq5`yr'90,"yr90_allsec")];
    mat colnames predtradq5`yr'90 = yr90_balcadvq5;
    mat roweq predtradq5`yr'90 = `margin'_predtradq5;
    * check computation;
    complist `margin';
    };
  // predtarfq5: effects within top-compadv quartile, fix export status (indexp) at sample mean;
  foreach yr in 92 94 98 {;
    disp; disp in gr "margin " in ye "`margin'" in gr "; prediction for " in ye "`yr'90";
    mat tradvdif`yr'90 = subs`margin'_tradvars`yr'_aerrr_tbl - subs`margin'_tradvars90_aerrr_tbl;
    mat idmat_trad = I(`rows');
    local rownames : rownames subs`margin'_meff;
    mat rownames idmat_trad = `rownames';
    mat colnames idmat_trad = `rownames';
    local tradvars "";
    foreach var of local rownames {;
      local col "-";
      if substr("`var'",-11,11)=="firm_indexp" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = 0; matname idmat_trad 0, columns(`col') explicit; };
      if substr("`var'",- 8, 8)=="_balcadv" {;           local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_q5"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv_q5, columns(`col') explicit; };
      if substr("`var'",-11,11)=="_balcadv_90" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_q5"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _subs_balcadv_q5, columns(`col') explicit; };
      if substr("`var'",-16,16)=="_tarfoutp_indexp" {;   local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"firm_indexp"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _firm_indexp, columns(`col') explicit; };
      if substr("`var'",-16,16)=="_tarfintm_indexp" {;   local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"firm_indexp"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _firm_indexp, columns(`col') explicit; };
      if substr("`var'",-15,15)=="_indexp_balcadv" {;    local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"firm_indexp"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")] * subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_q5"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _firm_indexp_subs_balcadv_q5, columns(`col') explicit; };
      if substr("`var'",-18,18)=="_indexp_balcadv_90" {; local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"firm_indexp"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")] * subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"subs_balcadv_q5"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _firm_indexp_subs_balcadv_q5, columns(`col') explicit; };
      if substr("`var'",-11,11)=="_notindprim" {;        local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"notindprim"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _notindprim, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indyoung" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indyoung"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indyoung, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indwhite" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indwhite"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indwhite, columns(`col') explicit; };
      if substr("`var'",- 9, 9)=="_indfemal" {;          local col : list posof "`var'" in rownames; mat idmat_trad[`col',`col'] = subs`margin'_tradvars90_aerrr_tbl[rownumb(subs`margin'_tradvars90_aerrr_tbl,"indfemal"),colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")]; matname idmat_trad _indfemal, columns(`col') explicit; };
      disp in ye "`col': `var'";
      if index("`var'","subs_tarfoutp_indexp_balcadv_90")>0  local tradvars "`tradvars' subs_tarfoutp";
      if index("`var'","subs_tarfoutp")>0 & index("`var'","subs_tarfoutp_indexp_balcadv_90")==0  local tradvars "`tradvars' subs_tarfoutp";
      if index("`var'","subs_tarfintm_indexp_balcadv_90")>0  local tradvars "`tradvars' subs_tarfintm";
      if index("`var'","subs_tarfintm")>0 & index("`var'","subs_tarfintm_indexp_balcadv_90")==0  local tradvars "`tradvars' subs_tarfintm";
      if index("`var'","subs_reffpen")>0   local tradvars "`tradvars' subs_reffpen";
      if index("`var'","firm_indexp")>0    local tradvars "`tradvars' firm_indexp";
      };
    matins tradvdif`yr'90, m(tradvdifuse) ifr(`tradvars') over;
    mat predtarfq5`yr'90 = ( idmat_trad * subs`margin'_meff )' * tradvdifuse;
    mat predtarfq5`yr'90 = predtarfq5`yr'90[1...,colnumb(predtarfq5`yr'90,"yr90_allsec")];
    mat colnames predtarfq5`yr'90 = yr90_balcadvq5;
    mat roweq predtarfq5`yr'90 = `margin'_predtarfq5;
    * check computation;
    complist `margin';
    };

  // All-sector table of trade variable changes and their predictions;
  mat _tradlvl`margin' = subs`margin'_tradvars90_aerrr_tbl[1...,colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")] , subs`margin'_tradvars92_aerrr_tbl[1...,colnumb(subs`margin'_tradvars92_aerrr_tbl,"yr92_allsec")] , subs`margin'_tradvars94_aerrr_tbl[1...,colnumb(subs`margin'_tradvars94_aerrr_tbl,"yr94_allsec")] , subs`margin'_tradvars98_aerrr_tbl[1...,colnumb(subs`margin'_tradvars98_aerrr_tbl,"yr98_allsec")];
  matorder _tradlvl`margin', m(_tradlvl`margin') over ifr(subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp);
  mat _tradlvl`margin' = J(4,1,.) , _tradlvl`margin';
  mat rownames _tradlvl`margin' = `margin':subs_tarfoutp_lvl `margin':subs_tarfintm_lvl `margin':subs_reffpen_lvl `margin':firm_indexp_lvl;
  mat _tradchg`margin' = subs`margin'_tradvars92_aerrr_tbl[1...,colnumb(subs`margin'_tradvars92_aerrr_tbl,"yr92_allsec")] - subs`margin'_tradvars90_aerrr_tbl[1...,colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")] , subs`margin'_tradvars94_aerrr_tbl[1...,colnumb(subs`margin'_tradvars94_aerrr_tbl,"yr94_allsec")] - subs`margin'_tradvars90_aerrr_tbl[1...,colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")] , subs`margin'_tradvars98_aerrr_tbl[1...,colnumb(subs`margin'_tradvars98_aerrr_tbl,"yr98_allsec")] - subs`margin'_tradvars90_aerrr_tbl[1...,colnumb(subs`margin'_tradvars90_aerrr_tbl,"yr90_allsec")];
  matorder _tradchg`margin', m(_tradchg`margin') over ifr(subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp);
  mat _tradchg`margin' = J(4,1,.) , J(4,1,0) , _tradchg`margin';
  mat rownames _tradchg`margin' = `margin':subs_tarfoutp_chg `margin':subs_tarfintm_chg `margin':subs_reffpen_chg `margin':firm_indexp_chg;
  mat _tradeff`margin' = ( predtrad9290[1...,1] \ predtarf9290[1...,1] \ predtarfexp9290[1...,1] \ predtradq59290[1...,1] \ predtarfq59290[1...,1] ) , ( predtrad9490[1...,1] \ predtarf9490[1...,1] \ predtarfexp9490[1...,1] \ predtradq59490[1...,1] \ predtarfq59490[1...,1] ) , ( predtrad9890[1...,1] \ predtarf9890[1...,1] \ predtarfexp9890[1...,1] \ predtradq59890[1...,1] \ predtarfq59890[1...,1] );
  local rows = rowsof(_tradeff`margin');
  local rownames : rowfullnames _tradeff`margin';
  mat _tradeff`margin' = J(`rows',1,.) , J(`rows',1,0) , _tradeff`margin';
  mat rownames _tradeff`margin' = `rownames';
  mat colnames _tradchg`margin' = y1986 y1990 y1992 y1994 y1998;
  mat colnames _tradlvl`margin' = y1986 y1990 y1992 y1994 y1998;
  mat colnames _tradeff`margin' = y1986 y1990 y1992 y1994 y1998;
  };
mat drop tradvdif9290 tradvdif9490 tradvdif9890 idmat_trad tradvdifuse;
# delimit cr

// Table of predicted displacement effects
matload labstataer_tbl, dropall p(brazrloc/tex/v4/labor) over missing(.)
matorder labstataer_tbl, m(labstataer_tbl) ifr(1986 1990 1992 1994 1998)
matorder labstataer_tbl, m(labstataer_tbl) ifc(natl_manuf_inddspl natl_manuf_indhire)
mat turnpred_tbl =  labstataer_tbl ' \ J(2,5,.)
mat drop labstataer_tbl
mat rownames turnpred_tbl = dspl:pop hire:pop dspl:chg hire:chg
mat colnames turnpred_tbl = y1986 y1990 y1992 y1994 y1998
foreach yr in 90 92 94 98 {
  mat turnpred_tbl[3,colnumb(turnpred_tbl,"y19`yr'")] = turnpred_tbl[1,colnumb(turnpred_tbl,"y19`yr'")] - turnpred_tbl[1,colnumb(turnpred_tbl,"y1990")]
  mat turnpred_tbl[4,colnumb(turnpred_tbl,"y19`yr'")] = turnpred_tbl[2,colnumb(turnpred_tbl,"y19`yr'")] - turnpred_tbl[2,colnumb(turnpred_tbl,"y1990")]
  }
* mat turnpred_tbl = turnpred_tbl \ _tradlvldspl \ _tradlvlhire \ _tradchgdspl \ _tradchghire // displacement and hiring figures for sector variables similar
mat turnpred_tbl = turnpred_tbl \ _tradlvldspl \ _tradchgdspl
mat rownames turnpred_tbl = dspl:pop hire:pop dspl:chg hire:chg seclvl:subs_tarfoutp seclvl:subs_tarfintm seclvl:subs_reffpen seclvl:firm_indexp secchg:subs_tarfoutp secchg:subs_tarfintm secchg:subs_reffpen secchg:firm_indexp
mat drop _tradlvldspl _tradlvlhire _tradchgdspl _tradchghire
mat turnpred_tbl = turnpred_tbl \ _tradeffdspl \ _tradeffhire
mat drop _tradeffdspl _tradeffhire

// labor productivity at accession margin
matload ollpak_alt_tbl, p(brazrloc/tex/v4/tfp) over missing(.)
matorder ollpak_alt_tbl, m(ollpak_alt_tbl) ifr(90 92 94 98) over
matorder ollpak_alt_tbl, m(ollpak_alt_tbl) ifc(agglnlp) over
mat ollpak_alt_tbl = ollpak_alt_tbl ' - J(1,4,1)  // 1990: 1
matload aer_frmlnlp_tbl, p(brazrloc/tex/v4/natl/reg) over missing(.)
matorder aer_frmlnlp_tbl, m(aer_frmlnlp_tbl) ifr(firm_lnlp) over
matorder aer_frmlnlp_tbl, m(aer_frmlnlp_tbl) ifc(hire_clogit_lnlp) over
local lnlpcoef = aer_frmlnlp_tbl[1,1]
mat hire_predlnlp = J(1,1,.) , ollpak_alt_tbl * `lnlpcoef' * `phatsecyrhire'*(1-`phatsecyrhire')
matrix colnames hire_predlnlp = y1986 y1990 y1992 y1994 y1998
matrix rownames hire_predlnlp = hire:predlp_lnlp
mat turnpred_tbl = turnpred_tbl \ hire_predlnlp

// prediction table output
mat rename turnpred_tbl turnpredaerrr_tbl
est2tex turnpredaerrr, replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3)
matorder turnpredaerrr_tbl, m(turnpredaerrr_paper_tbl) ifc(y1990 y1992 y1994 y1998)
est2tex turnpredaerrr_paper, replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3)

// keep turnover prediction matrix for later use, drop other matrices
matorder turnpredaerrr_paper_tbl, m(turnpred) ifr(dspl_predtarf:clogit_intract30_90 dspl_predtarfexp:clogit_intract30_90 dspl_predtarfq5:clogit_intract30_90 hire_predtarf:clogit_intract30_90 hire_predtarfexp:clogit_intract30_90 hire_predtarfq5:clogit_intract30_90 hire:predlp_lnlp)
foreach margin in dspl hire {
  mat drop subs`margin'_tradvars90_aerrr_tbl subs`margin'_meff subs`margin'_coef_aerrr_tbl
  foreach yr in 92 94 98 {
    mat drop subs`margin'_tradvars`yr'_aerrr_tbl
    }
  }
foreach yr in 92 94 98 {
  mat drop predtrad`yr'90 predtarf`yr'90 predtarfexp`yr'90 predtradq5`yr'90 predtarfq5`yr'90
  }


/* AUXILIARY DATA */

// Monthly Minimum Wage in USD
tempfile minwage
use "brazaux/auxil/minwage.dta", clear
gen int ano = year(day)
gen int mo = month(day)
keep ano mo salusd
sort ano mo
collapse (mean) salusd, by(ano)
label var ano "Calendar year"
label var salusd "Minimum Wage in USD (nom. rate)"
keep if ano>=1986 & ano<=2001
sort ano
save `minwage'

// Annual GDP and Minimum Wage in USD
tempfile gdpwage
insheet using "brazrloc/auxil/origs/pib.csv", comma clear
keep ano pib_corrente_usd pib_pc_corrente_usd
rename pib_corrente_usd gdpusd
rename pib_pc_corrente_usd gdppcusd
label var ano "Calendar year"
label var gdpusd "GDP in USD (nom. rate)"
label var gdppcusd "GDP p.c. in USD (nom. rate)"
keep if ano>1985 & ano<2002
sort ano
merge ano using `minwage'
qui count if _m~=3
if `r(N)'~=0  STOP
drop _m
replace salusd = salusd*12
label var salusd "Ann. Min. Wage in USD (nom. rate)"
gen gdppc_sal_ratio = gdppcusd/salusd
label var gdppc_sal_ratio "GDP p.c./Ann. Min. Wage"
sort ano
* est2tex gdpwage, p(brazrloc/tex/v4/gdp) in %4tex/gdp-impact.do
drop gdppcusd gdppc_sal_ratio
sort ano
save `gdpwage'


/* TRANSITIONS FROM FORMAL EMPLOYMENT TO STATUS OUTSIDE FORMALITY; WAGES */

* "brazrloc/tex/v4/pme/form2nonform_86_99_tbl.dta" produced in %4tex/gdp-impact.do
matload form2nonform_86_99_tbl, dropall over missing(.) p(brazrloc/tex/v4/pme)
* "brazrloc/tex/v4/gdp/gdpwage_tbl.dta" produced in %4tex/gdp-impact.do
matload gdpwage_tbl, dropall over missing(.) p(brazrloc/tex/v4/gdp)


/* WAGE-BILL LOSS IN GDP FROM REALLOCATION DURATIONS AND FAILED REALLOCATIONS */

matorder gdpwage_tbl, m(gdpwage_tbl) over ifc(gdpusd salusd)
matorder gdpwage_tbl, m(gdpwage_tbl) over ifr(y1990 y1991 y1992 y1993 y1994 y1995 y1996 y1997 y1998)
mat gdpwage_tbl = gdpwage_tbl '
local colyrs : colnames gdpwage_tbl
matorder indnorloc12mbygrp_tbl, m(indnorloc_gdp) ifr(any:r(mean) any:r(N) any:mean_rem_media)
matorder indnorloc_gdp, m(indnorloc_gdp) ifc(indnorloc1990 indnorloc1991 indnorloc1992 indnorloc1993 indnorloc1994 indnorloc1995 indnorloc1996 indnorloc1997 indnorloc1998) over
mat drop indnorloc12mbygrp_tbl
matorder mo2rehr12mbygrp_tbl, m(mo2rehr_gdp) ifr(any:r(mean))
matorder mo2rehr_gdp, m(mo2rehr_gdp) ifc(mo2rehir1990 mo2rehir1991 mo2rehir1992 mo2rehir1993 mo2rehir1994 mo2rehir1995 mo2rehir1996 mo2rehir1997 mo2rehir1998) over
mat drop mo2rehr12mbygrp_tbl
mat gdploss = J(4,9,.)
matrix rownames gdploss = chg:indnorloc chg:mo2rehr tbr:indnorloc tbr:mo2rehr
matrix colnames gdploss = `colyrs'
local j 0
forvalues ano = 1990/1998 {
  local j = `j' + 1
  mat gdploss[1,`j'] = ( (indnorloc_gdp[1,`j']-indnorloc_gdp[1,1]) )
  mat gdploss[2,`j'] = ( ((mo2rehr_gdp[1,`j']-mo2rehr_gdp[1,1])/12) )
  mat gdploss[3,`j'] = ( (indnorloc_gdp[1,`j']-indnorloc_gdp[1,1]) * indnorloc_gdp[2,`j']*100 * indnorloc_gdp[3,`j']*12 * gdpwage_tbl[2,`j'] / 1000000 ) / gdpwage_tbl[1,`j']
  mat gdploss[4,`j'] = ( ((mo2rehr_gdp[1,`j']-mo2rehr_gdp[1,1])/12) * indnorloc_gdp[2,`j']*100 * indnorloc_gdp[3,`j']*12 * gdpwage_tbl[2,`j'] / 1000000 ) / gdpwage_tbl[1,`j']
  }
mat _gdploss = J(2,9,.)
matrix rownames _gdploss = idle:indnorloc idle:mo2rehr
matrix colnames _gdploss = `colyrs'
foreach ano in 1990 1992 1994 1996 1998 {
  forvalues row = 1/2 {
    local anopl1 = `ano' + 1 - 1900
    mat _gdploss[`row',colnumb(_gdploss,"y`ano'")] = gdploss[`row'+2,colnumb(gdploss,"y`ano'")] * form2nonform_86_99_tbl[rownumb(form2nonform_86_99_tbl,"formal_unemployed_fora_da_pea"),colnumb(form2nonform_86_99_tbl,"y`ano'_`anopl1'")]
    }
  }
mat gdploss = gdploss \ _gdploss
mat drop _gdploss
mat rename gdploss gdplossaer_tbl
est2tex gdplossaer, replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3)


/* OVERALL TABLE */

matload mo2rehr12mbygrp_tbl, p(brazrloc/tex/v4/natl/duration) dropall missing(.) over
matorder mo2rehr12mbygrp_tbl, m(mo2rehr12mbygrp_tbl) ifc(mo2rehir1986 mo2rehir1990 mo2rehir1992 mo2rehir1994 mo2rehir1998) over
matorder mo2rehr12mbygrp_tbl, m(mo2rehr12mbygrp_tbl) ifr(any:r(mean)) over
mat rownames mo2rehr12mbygrp_tbl = mo2rehr
matload indnorloc12mbygrp_tbl, p(brazrloc/tex/v4/natl/duration) dropall missing(.) over
matorder indnorloc12mbygrp_tbl, m(indnorloc12mbygrp_tbl) ifc(indnorloc1986 indnorloc1990 indnorloc1992 indnorloc1994 indnorloc1998) over
matorder indnorloc12mbygrp_tbl, m(indnorloc12mbygrp_tbl) ifr(any:r(mean) any:r(N)) over
foreach yr in 86 90 92 94 98 {  // scale to population size
  mat indnorloc12mbygrp_tbl[rownumb(indnorloc12mbygrp_tbl,"any:r(N)"),colnumb(indnorloc12mbygrp_tbl,"indnorloc19`yr'")] = indnorloc12mbygrp_tbl[rownumb(indnorloc12mbygrp_tbl,"any:r(N)"),colnumb(indnorloc12mbygrp_tbl,"indnorloc19`yr'")] * 100
  }
mat rownames indnorloc12mbygrp_tbl = indnorloc r(N)
mat _gdp_turnov_tbl = mo2rehr12mbygrp_tbl \ indnorloc12mbygrp_tbl
mat drop mo2rehr12mbygrp_tbl indnorloc12mbygrp_tbl
matorder _gdp_turnov_tbl, m(_gdp_turnov_tbl) over ifr(any:indnorloc any:mo2rehr any:r(N))
matorder rlocsucc_aer_tbl, m(rlocsucc_aer_tbl) ifr(mo2rehr:any mo2rehr:femal mo2rehr:young mo2rehr:notprim indnorloc:any indnorloc:femal indnorloc:young indnorloc:notprim)
mat _gdp_turnov_tbl = _gdp_turnov_tbl \ rlocsucc_aer_tbl
matorder _gdp_turnov_tbl, m(_gdp_turnov_tbl) over ifr(indnorloc:any indnorloc:femal indnorloc:young indnorloc:notprim mo2rehr:any mo2rehr:femal mo2rehr:young mo2rehr:notprim any:r(N))

matorder gdplossaer_tbl, m(gdp_turnov_tbl) ifc(y1990 y1992 y1994 y1998)
mat gdp_turnov_tbl = gdp_turnov_tbl \ turnpred
local rownames : rowfullnames gdp_turnov_tbl
mat gdp_turnov_tbl = J(13,1,.) , gdp_turnov_tbl
mat rownames gdp_turnov_tbl = `rownames'
mat gdp_turnov_tbl = _gdp_turnov_tbl \ gdp_turnov_tbl
mat drop _gdp_turnov_tbl
mat colnames gdp_turnov_tbl = y1986 y1990 y1992 y1994 y1998
matorder gdp_turnov_tbl, m(gdp_turnov_tbl) ifr(mo2rehr:any mo2rehr:femal mo2rehr:young mo2rehr:notprim chg:mo2rehr tbr:mo2rehr idle:mo2rehr indnorloc:any indnorloc:femal indnorloc:young indnorloc:notprim chg:indnorloc tbr:indnorloc idle:indnorloc any:r(N) dspl_predtarf:clogit_intract30_90 dspl_predtarfexp:clogit_intract30_90 dspl_predtarfq5:clogit_intract30_90 hire_predtarf:clogit_intract30_90 hire_predtarfexp:clogit_intract30_90 hire_predtarfq5:clogit_intract30_90 hire:predlp_lnlp) over
mat rename gdp_turnov_tbl gdp_turnovaerrr_tbl
est2tex gdp_turnovaerrr, replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3)

* Clean Up
mat drop rlocsucc_aer_tbl ollpak_alt_tbl aer_frmlnlp_tbl turnpred form2nonform_86_99_tbl gdpwage_tbl indnorloc_gdp mo2rehr_gdp gdplossaer_tbl gdp_turnovaerrr_tbl turnpredaerrr_paper_tbl turnpredaerrr_tbl hire_predlnlp multsal_indnorloc

log close


/* Matrix Use

predtrad
--------
subs_tarfoutp * 1
subs_tarfintm * 1
subs_reffpen * 1
firm_indexp * 1
subs_tarfoutp_indexp * firm_indexp
subs_tarfintm_indexp * firm_indexp
subs_tarfoutp_balcadv * subs_balcadv
subs_tarfintm_balcadv * subs_balcadv
subs_tarfoutp_indexp_balcadv * firm_indexp * subs_balcadv
subs_tarfintm_indexp_balcadv * firm_indexp * subs_balcadv
subs_tarfoutp_notindprim * notindprim
subs_tarfintm_notindprim * notindprim
subs_tarfoutp_indyoung * indyoung
subs_tarfintm_indyoung * indyoung
subs_tarfoutp_indwhite * indwhite
subs_tarfintm_indwhite * indwhite
subs_tarfoutp_indfemal * indfemal
subs_tarfintm_indfemal* indfemal

predtarf
--------
subs_tarfoutp * 1
subs_tarfintm * 1
subs_reffpen * 1
firm_indexp * 1
subs_tarfoutp_indexp * firm_indexp
subs_tarfintm_indexp * firm_indexp
subs_tarfoutp_balcadv * subs_balcadv
subs_tarfintm_balcadv * subs_balcadv
subs_tarfoutp_indexp_balcadv * firm_indexp * subs_balcadv
subs_tarfintm_indexp_balcadv * firm_indexp * subs_balcadv
subs_tarfoutp_notindprim * notindprim
subs_tarfintm_notindprim * notindprim
subs_tarfoutp_indyoung * indyoung
subs_tarfintm_indyoung * indyoung
subs_tarfoutp_indwhite * indwhite
subs_tarfintm_indwhite * indwhite
subs_tarfoutp_indfemal * indfemal
subs_tarfintm_indfemal* indfemal
*/
