version 8
set more off
set virtual on
clear
set trace off
set matsize 800

cd "$root"

capture mkdir "brazrloc/simul"
capture mkdir "brazrloc/simul/v4"

capture log close
log using "brazrloc/logs/simulation.log", replace


/* PNAD */
tempfile pnad
insheet using "brazrloc/simul/pnad.csv", comma clear
foreach var of varlist * {
  if "`var'"~="year" {
    gen _`var' = real(subinstr(`var',",","",.))
    drop `var'
    rename _`var' `var'
    }
  }
foreach newyear in 1991 1994 {
  expand 2 if year==`newyear'-1
  sort year
  replace year = `newyear' if year[_n-1]==`newyear'-1 & year[_n+1]==`newyear'+1
  replace tot=(tot[_n-1]+tot[_n+1])/2 if year==`newyear'
  replace nemp=(nemp[_n-1]/tot[_n-1]+nemp[_n+1]/tot[_n+1])*tot/2 if year==`newyear'
  replace form=(form[_n-1]/tot[_n-1]+form[_n+1]/tot[_n+1])*tot/2 if year==`newyear'
  }
rename year ano
rename tot pnad_totlabf
rename form pnad_totempl
gen pnad_totnonempl = pnad_totlabf - pnad_totempl
keep ano pnad_totlabf pnad_totempl pnad_totnonempl
foreach var of varlist pnad_* {
  replace `var' = `var'/1000000  // million persons
  }
label var ano "Calendar year"
label var pnad_totlabf "PNAD Persons 25 to 64 yrs. old"
label var pnad_totempl "PNAD Employment"
label var pnad_totnonempl "PNAD Nonemployment"
sort ano
save `pnad'


/* ESTIMATES */
matload aerrr_subm_tbl, p(brazrloc/tex/v4/natl10pct/reg) over missing(.) dropall
local dsplcoef = aerrr_subm_tbl[rownumb(aerrr_subm_tbl,"cnae_tarfoutp"),colnumb(aerrr_subm_tbl,"dspl_rais_secyrfe0")]
local hirecoef = aerrr_subm_tbl[rownumb(aerrr_subm_tbl,"cnae_tarfoutp"),colnumb(aerrr_subm_tbl,"hire_rais_secyrfe0")]


/* SIGNATURE GRAPH TARIFF DATA (from brazrloc/%stata/%2tab-graph/tariff-data.do) */

tempfile tariffs
use "brazaux/auxil/tariff-data.dta", clear
drop if year==98
gen _empl88 = employment if year==88
egen empl88 = mean(_empl88), by(niv50)
drop _empl88
collapse (mean) tarfoutp [w=empl88], by(year) fast cw
rename year ano
replace ano = ano + 1900
sort ano
save `tariffs'


/* 12-MONTHS RATES */

local dur 12
use statmo ano month inddspl indhire indfind using "brazrloc/simul/v4/connect-stats-natl-`dur'm", clear
sort statmo
gen _indhire = indhire if month==1 
replace _indhire =   (1-indhire[_n-1])*indhire if month==2
replace _indhire =   (1-indhire[_n-2])*(1-indhire[_n-1])*indhire if month==3
replace _indhire =   (1-indhire[_n-3])*(1-indhire[_n-2])*(1-indhire[_n-1])*indhire if month==4
replace _indhire =   (1-indhire[_n-4])*(1-indhire[_n-3])*(1-indhire[_n-2])*(1-indhire[_n-1])*indhire if month==5
replace _indhire =   (1-indhire[_n-5])*(1-indhire[_n-4])*(1-indhire[_n-3])*(1-indhire[_n-2])*(1-indhire[_n-1])*indhire if month==6
replace _indhire =   (1-indhire[_n-6])*(1-indhire[_n-5])*(1-indhire[_n-4])*(1-indhire[_n-3])*(1-indhire[_n-2])*(1-indhire[_n-1])*indhire if month==7
replace _indhire =   (1-indhire[_n-7])*(1-indhire[_n-6])*(1-indhire[_n-5])*(1-indhire[_n-4])*(1-indhire[_n-3])*(1-indhire[_n-2])*(1-indhire[_n-1])*indhire if month==8
replace _indhire =   (1-indhire[_n-8])*(1-indhire[_n-7])*(1-indhire[_n-6])*(1-indhire[_n-5])*(1-indhire[_n-4])*(1-indhire[_n-3])*(1-indhire[_n-2])*(1-indhire[_n-1])*indhire if month==9
replace _indhire =   (1-indhire[_n-9])*(1-indhire[_n-8])*(1-indhire[_n-7])*(1-indhire[_n-6])*(1-indhire[_n-5])*(1-indhire[_n-4])*(1-indhire[_n-3])*(1-indhire[_n-2])*(1-indhire[_n-1])*indhire if month==10
replace _indhire =  (1-indhire[_n-10])*(1-indhire[_n-9])*(1-indhire[_n-8])*(1-indhire[_n-7])*(1-indhire[_n-6])*(1-indhire[_n-5])*(1-indhire[_n-4])*(1-indhire[_n-3])*(1-indhire[_n-2])*(1-indhire[_n-1])*indhire if month==11
replace _indhire = (1-indhire[_n-11])*(1-indhire[_n-10])*(1-indhire[_n-9])*(1-indhire[_n-8])*(1-indhire[_n-7])*(1-indhire[_n-6])*(1-indhire[_n-5])*(1-indhire[_n-4])*(1-indhire[_n-3])*(1-indhire[_n-2])*(1-indhire[_n-1])*indhire if month==12
egen yrmo_indhire = sum(_indhire), by(ano)
gen _inddspl = inddspl if month==12 
replace _inddspl = (1-inddspl)*inddspl[_n+1] if month==11
replace _inddspl = (1-inddspl)*(1-inddspl[_n+1])*inddspl[_n+2] if month==10
replace _inddspl = (1-inddspl)*(1-inddspl[_n+1])*(1-inddspl[_n+2])*inddspl[_n+3] if month==9
replace _inddspl = (1-inddspl)*(1-inddspl[_n+1])*(1-inddspl[_n+2])*(1-inddspl[_n+3])*inddspl[_n+4] if month==8
replace _inddspl = (1-inddspl)*(1-inddspl[_n+1])*(1-inddspl[_n+2])*(1-inddspl[_n+3])*(1-inddspl[_n+4])*inddspl[_n+5] if month==7
replace _inddspl = (1-inddspl)*(1-inddspl[_n+1])*(1-inddspl[_n+2])*(1-inddspl[_n+3])*(1-inddspl[_n+4])*(1-inddspl[_n+5])*inddspl[_n+6] if month==6
replace _inddspl = (1-inddspl)*(1-inddspl[_n+1])*(1-inddspl[_n+2])*(1-inddspl[_n+3])*(1-inddspl[_n+4])*(1-inddspl[_n+5])*(1-inddspl[_n+6])*inddspl[_n+7] if month==5
replace _inddspl = (1-inddspl)*(1-inddspl[_n+1])*(1-inddspl[_n+2])*(1-inddspl[_n+3])*(1-inddspl[_n+4])*(1-inddspl[_n+5])*(1-inddspl[_n+6])*(1-inddspl[_n+7])*inddspl[_n+8] if month==4
replace _inddspl = (1-inddspl)*(1-inddspl[_n+1])*(1-inddspl[_n+2])*(1-inddspl[_n+3])*(1-inddspl[_n+4])*(1-inddspl[_n+5])*(1-inddspl[_n+6])*(1-inddspl[_n+7])*(1-inddspl[_n+8])*inddspl[_n+9] if month==3
replace _inddspl = (1-inddspl)*(1-inddspl[_n+1])*(1-inddspl[_n+2])*(1-inddspl[_n+3])*(1-inddspl[_n+4])*(1-inddspl[_n+5])*(1-inddspl[_n+6])*(1-inddspl[_n+7])*(1-inddspl[_n+8])*(1-inddspl[_n+9])*inddspl[_n+10] if month==2
replace _inddspl = (1-inddspl)*(1-inddspl[_n+1])*(1-inddspl[_n+2])*(1-inddspl[_n+3])*(1-inddspl[_n+4])*(1-inddspl[_n+5])*(1-inddspl[_n+6])*(1-inddspl[_n+7])*(1-inddspl[_n+8])*(1-inddspl[_n+9])*(1-inddspl[_n+10])*inddspl[_n+11] if month==1
egen yrmo_inddspl = sum(_inddspl), by(ano)
drop _*
foreach var of varlist inddspl indhire indfind {
  rename `var' mo_`var'
  }
sort ano
merge ano using "brazrloc/simul/v4/connect-stats-natl-`dur'm-annual"
tab _m
summ yrmo_indhire indhire yrmo_inddspl inddspl
compare yrmo_indhire indhire
compare yrmo_inddspl inddspl


/* 48-MONTHS RATES */

local dur 48
local strtyr = 1986
local finlyr = 1997
* local strtyr = 1986 + `dur'/12
* local finlyr = 2001 - `dur'/12
use statmo ano month inddspl indhire indfind using "brazrloc/simul/v4/connect-stats-natl-`dur'm", clear
sort ano
merge ano using "brazrloc/simul/v4/connect-stats-natl-`dur'm-annual"
tab _m
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
foreach var of varlist inddspl indhire indfind mo_inddspl mo_indhire mo_indfind mo_indnorloc indnorloc mo_mo2rehir mo2rehir mo_totempl mo_totnonempl {
  local `var' : variable label `var'
  }
collapse (mean) inddspl indhire indfind mo_inddspl mo_indhire mo_indfind mo_indnorloc indnorloc mo_mo2rehir mo2rehir mo_totempl mo_totnonempl, by(ano) fast
foreach var of varlist inddspl indhire indfind mo_inddspl mo_indhire mo_indfind mo_indnorloc indnorloc mo_mo2rehir mo2rehir mo_totempl mo_totnonempl {
  label var `var' "``var''"
  }
drop  mo_inddspl mo_indhire mo_indfind mo_indnorloc mo_mo2rehir
rename mo_totempl totempl

* Infer job finding rates (1997-2000 steady state) and Nonemployment
gsort -ano
gen infer_indfind = 1 - indnorloc^(1/4) if ano==1997
egen _infer_indfind = max(infer_indfind)
replace infer_indfind = _infer_indfind if ano>1997
replace infer_indfind = 1 - indnorloc/((1-infer_indfind[_n-1])*(1-infer_indfind[_n-2])*(1-infer_indfind[_n-3])) if ano<1997
gen infer_totnonempl = totempl * (indhire/infer_indfind)
gen infer_ratio_nonempl_empl = indhire/infer_indfind
drop _infer_indfind mo_totnonempl
sort ano
gen _indnorloc = (1-infer_indfind)*(1-infer_indfind[_n+1])*(1-infer_indfind[_n+2])*(1-infer_indfind[_n+3]) if ano<=1997
compare indnorloc _indnorloc
qui count if float(indnorloc)~=float(_indnorloc)
if `r(N)'>0  STOP  // inconsistent inference
drop _indnorloc

* Compute mean reallocation durations under inferred finding rates
gen infer_mo2rehir = ( 0*infer_indfind + 1*(1-infer_indfind)*infer_indfind[_n+1] + 2*(1-infer_indfind)*(1-infer_indfind[_n+1])*infer_indfind[_n+2] + 3*(1-infer_indfind)*(1-infer_indfind[_n+1])*(1-infer_indfind[_n+2])*infer_indfind[_n+3] ) * 12 / (1-indnorloc)
gen ratio_mo2rehir = infer_mo2rehir / mo2rehir
list ano infer_mo2rehir ratio_mo2rehir

* Compute separation-accession rate difference from employment change, from nonemployment change, and from rates
gen ratediff = indhire - inddspl
gen empl_ratediff = (totempl[_n+1]-totempl)/totempl
gen nonempl_ratediff = -(infer_totnonempl[_n+1]-infer_totnonempl)/infer_totnonempl
list ratediff empl_ratediff nonempl_ratediff

* Obtain PNAD information
merge ano using `pnad'
tab _m
qui count if _m==2
if `r(N)'>0  STOP
drop _m
graph twoway connected pnad_totempl pnad_totnonempl ano if ano>=1988 & ano<=`finlyr', xlab(1988/`finlyr') ylab(10(10)60) ytitle("Million persons") legend( label(1 "PNAD Employment") label(2 "PNAD Nonemployment") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/pnad-totnonempl`dur'm-annual.eps", replace
more
graph twoway connected pnad_totempl pnad_totnonempl ano if ano>=1990 & ano<=`finlyr', xlab(1990/`finlyr') ylab(10(10)60) ytitle("Million persons") legend( label(1 "PNAD Employment") label(2 "PNAD Nonemployment") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/pnad-totnonempl`dur'm-annual-1990.eps", replace
more

* Graph inferred statistics
label var ano "Calendar year"
label var inddspl "Separation rate"
label var indhire "Accession rate"
label var infer_indfind "Implied Finding rate"
label var totempl "Employment"
label var infer_totnonempl "Implied Nonemployment"
gen _infer_mo2rehir = infer_mo2rehir if ano==1989 | ano==1992 | ano==1997
gen _mo2rehir = mo2rehir if ano==1989 | ano==1992 | ano==1997
format _infer_mo2rehir _mo2rehir %9.2f
graph twoway connected infer_indfind ano if ano>=`strtyr' & ano<=`finlyr', xlab(`strtyr'/`finlyr') yaxis(1) || connected indnorloc ano if ano>=`strtyr' & ano<=`finlyr', yaxis(2) ||, xtitle("Calendar year") ylabel(0(0.1)0.5, axis(1)) yscale(axis(1) r(0 1)) ytitle("Implied Frequency", axis(1)) yscale(axis(2) r(.05 .25)) ytitle("Nonemployed without new job (share)", axis(2)) ylabel(.05(.05).25, axis(2)) yline(.15 .175 .2 .225 .25, axis(2) lcolor(gs14)) legend( order(1 2) label(1 "Implied Finding rate") label(2 "Reallocation Failure") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/infer-indfind-indnorloc48-86-98.eps", replace
more
graph twoway sc _infer_mo2rehir _mo2rehir ano if ano>=`strtyr' & ano<=`finlyr', mlabel(_infer_mo2rehir _mo2rehir) mlabposition(11 11) mlabcolor(black black) msymbol(i i) yaxis(1) || connected infer_mo2rehir mo2rehir ano if ano>=`strtyr' & ano<=`finlyr', xlab(`strtyr'/`finlyr') yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) ||, xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(5 15)) ytitle("", axis(1)) yscale(axis(2) r(5 15)) ytitle("Nonemployment until first new job (months)", axis(2)) yline(6 7 8 9 10 11 12 13 14, axis(2) lcolor(gs14))  ylab(6 8 10 12 14, axis(2)) legend( order(3 4) label(3 "Implied Realloc. Durations") label(4 "Realloc. Durations") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/infer-mo2rehir48-86-98.eps", replace
more
graph twoway connected inddspl indhire ano if ano>=`strtyr' & ano<=`finlyr', xlab(`strtyr'/`finlyr') ytitle("Frequency") legend( label(1 "Separation rate") label(2 "Accession rate") ) graphregion(color(white)) scheme(sj) msymbol(X T D i) clpattern(solid dash_dot longdash_dot dot) ylabel(0(0.1)0.5)
graph export "brazrloc/graphs/v4/natl/simul/infer-dsplhire`dur'm-annual.eps", replace
more
graph twoway connected infer_indfind indhire ano if ano>=`strtyr' & ano<=`finlyr', xlab(`strtyr'/`finlyr') ytitle("Frequency") legend( label(1 "Implied Finding rate") label(2 "Accession rate") ) graphregion(color(white)) scheme(sj) msymbol(D T i) clpattern(longdash_dot dash_dot dot) ylabel(0(0.1)0.5)
graph export "brazrloc/graphs/v4/natl/simul/infer-findhire`dur'm-annual.eps", replace
more
graph twoway connected totempl infer_totnonempl ano if ano>=`strtyr' & ano<=`finlyr', xlab(`strtyr'/`finlyr') ytitle("Million persons") legend( label(1 "RAIS Employment") label(2 "Implied Nonemployment") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/infer-totnonempl`dur'm-annual.eps", replace
more
graph twoway connected totempl infer_totnonempl ano if ano>=1990 & ano<=`finlyr', xlab(1990/`finlyr') ylab(10(10)60) ytitle("Million persons") legend( label(1 "RAIS Employment") label(2 "Implied Nonemployment") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/infer-totnonempl`dur'm-annual-1990.eps", replace
more
drop _infer_mo2rehir _mo2rehir

* Obtain annual tariff series and compute three counterfactuals: 90 (fix at 1990), min (piecemeal reform by 1996), max (drop to 1995 in 1990)
sort ano
merge ano using `tariffs'
tab _merge
qui count if _m~=3 & ano<=1997
if `r(N)'>0  STOP
drop _m
local tarfini = tarfoutp[5]  // 1990
local tarffin = tarfoutp[12]  // 1997
gen tarfchg90 = `tarfini'
replace tarfchg90 = tarfchg90-tarfoutp
replace tarfchg90 = 0 if ano<1990
gen tarfchgmin = (`tarfini'-`tarffin')/7 * (12-_n) + (`tarffin'-tarfoutp) if ano>=1990
replace tarfchgmin = 0 if tarfchgmin==. & ano<=1997
gen tarfchgmax = `tarffin'-tarfoutp if ano>=1991
replace tarfchgmax = 0 if tarfchgmax==. & ano<=1997
gen simul_tarfoutp = tarfoutp + tarfchg90
gen simulmin_tarfoutp = tarfoutp + tarfchgmin
gen simulmax_tarfoutp = tarfoutp + tarfchgmax

* Simulated separation and accession rates under alternative tariffs (90 min max), and reallocation failure
sort ano
gen simul_inddspl = inddspl + tarfchg90*`dsplcoef'
gen simul_indhire = indhire + tarfchg90*`hirecoef'
gen simulmin_inddspl = inddspl + tarfchgmin*`dsplcoef'
gen simulmin_indhire = indhire + tarfchgmin*`hirecoef'
gen simulmax_inddspl = inddspl + tarfchgmax*`dsplcoef'
gen simulmax_indhire = indhire + tarfchgmax*`hirecoef'
gen simuladd_indfind = infer_indfind + tarfchg90*`hirecoef'
replace simuladd_indfind = simuladd_indfind[_n-1] if ano>1997
gen simulfix_indfind = simul_indhire / infer_ratio_nonempl_empl
replace simulfix_indfind = simulfix_indfind[_n-1] if ano>1997
gen _indnorloc = (1-infer_indfind)*(1-infer_indfind[_n+1])*(1-infer_indfind[_n+2])*(1-infer_indfind[_n+3])
gen simuladd_indnorloc = (1-simuladd_indfind)*(1-simuladd_indfind[_n+1])*(1-simuladd_indfind[_n+2])*(1-simuladd_indfind[_n+3])
gen simulfix_indnorloc = (1-simulfix_indfind)*(1-simulfix_indfind[_n+1])*(1-simulfix_indfind[_n+2])*(1-simulfix_indfind[_n+3])
order ano inddspl simul_inddspl simulmin_inddspl simulmax_inddspl indhire simul_indhire simulmin_indhire simulmax_indhire infer_indfind simuladd_indfind simulfix_indfind indnorloc simuladd_indnorloc simulfix_indnorloc _indnorloc
drop _indnorloc

* Simulated separation-accession rate difference as well as nonemployment-employment-ratio (90 tariffs), and reallocation failure
gen simul_ratediff = simul_indhire - simul_inddspl
gen simul_totempl = totempl if ano<=1991
* replace simul_totempl = (simul_ratediff[_n-1] - ratediff[_n-1])*simul_totempl[_n-1] + simul_totempl[_n-1] if ano>=1991
replace simul_totempl = (simul_ratediff[_n-1] - ratediff[_n-1])*simul_totempl[_n-1] + totempl if ano>=1991
gen simul_totnonempl = infer_totnonempl if ano<=1991
* replace simul_totnonempl = -(simul_ratediff[_n-1] - ratediff[_n-1])*simul_totempl[_n-1] + simul_totnonempl[_n-1] if ano>=1991
replace simul_totnonempl = -(simul_ratediff[_n-1] - ratediff[_n-1])*simul_totempl[_n-1] + infer_totnonempl if ano>=1991
gen simul1_ratio_nonempl_empl = simul_totnonempl/simul_totempl
list ano ratediff empl_ratediff nonempl_ratediff simul_ratediff simul_totempl totempl simul_totnonempl infer_totnonempl
gen simul2_ratio_nonempl_empl = infer_ratio_nonempl_empl if ano<=1990
replace simul2_ratio_nonempl_empl = ( ((-(simul_indhire[_n-1]-simul_inddspl[_n-1])+simul2_ratio_nonempl_empl[_n-1])/((simul_indhire[_n-1]-simul_inddspl[_n-1])+1)) / ((-(indhire[_n-1]-inddspl[_n-1])+simul2_ratio_nonempl_empl[_n-1])/((indhire[_n-1]-inddspl[_n-1])+1)) ) * simul2_ratio_nonempl_empl[_n-1] if ano>=1991
list ano simul_totempl totempl simul_totnonempl infer_totnonempl simul1_ratio_nonempl_empl simul2_ratio_nonempl_empl infer_ratio_nonempl_empl
gen simulvar_indfind = simul_indhire / simul1_ratio_nonempl_empl
replace simulvar_indfind = simulvar_indfind[_n-1] if ano>1997
gen simulvar_indnorloc = (1-simulvar_indfind)*(1-simulvar_indfind[_n+1])*(1-simulvar_indfind[_n+2])*(1-simulvar_indfind[_n+3])
order ano inddspl simul_inddspl indhire simul_indhire infer_indfind simuladd_indfind simulfix_indfind simulvar_indfind indnorloc simuladd_indnorloc simulfix_indnorloc simulvar_indnorloc

* Simulated nonemployment and employment (90 tariffs), finding rate and reallocation failure, adjusted for annual nonemployment updating (pnadinfer_ratio_nonempl_empl)
gen pnadinfer_ratio_nonempl_empl = (indhire/infer_indfind) / (pnad_totnonempl/pnad_totempl)
gen simulpnad_totempl = pnad_totempl if ano<=1991
replace simulpnad_totempl = (simul_ratediff[_n-1] - ratediff[_n-1])*simulpnad_totempl[_n-1] + pnad_totempl if ano>=1991
gen simulpnad_totnonempl = pnad_totnonempl if ano<=1991
replace simulpnad_totnonempl = -(simul_ratediff[_n-1] - ratediff[_n-1])*simulpnad_totempl[_n-1] + pnad_totnonempl if ano>=1991
gen simulpnad_indfind = ( simul_indhire / (simulpnad_totnonempl/simulpnad_totempl) ) / pnadinfer_ratio_nonempl_empl
replace simulpnad_indfind = simulpnad_indfind[_n-1] if ano>1997
replace simulpnad_indfind = infer_indfind if ano<=1990
gen simulpnad_indnorloc = (1-simulpnad_indfind)*(1-simulpnad_indfind[_n+1])*(1-simulpnad_indfind[_n+2])*(1-simulpnad_indfind[_n+3])
graph twoway connected simulpnad_totempl simulpnad_totnonempl ano if ano>=1988 & ano<=`finlyr', xlab(1988/`finlyr') ytitle("Million persons") legend( label(1 "Simul. PNAD Employment") label(2 "Simul. PNAD Nonempl.") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/simulpnad-totnonempl`dur'm-annual.eps", replace
more
graph twoway connected simulpnad_totempl simulpnad_totnonempl ano if ano>=1990 & ano<=`finlyr', xlab(1990/`finlyr') ylab(10(10)60)  ytitle("Million persons") legend( label(1 "Simul. PNAD Employment") label(2 "Simul. PNAD Nonempl.") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/simulpnad-totnonempl`dur'm-annual-1990.eps", replace
more
graph twoway connected simulfix_indfind simulvar_indfind simulpnad_indfind infer_indfind ano if ano>=1990 & ano<=`finlyr', xlab(1990/`finlyr') ytitle("Job Finding Rates") legend( label(1 "Fixed Nonempl./empl.") label(2 "RAIS Sim. Nonempl./empl.") label(3 "PNAD Sim. Nonempl./empl.") label(4 "Observed (implied)") ) graphregion(color(white)) scheme(sj) msymbol(T D C i) clpattern(dot dash_dot dash solid)
graph export "brazrloc/graphs/v4/natl/simul/simul-indfind-`dur'm-annual.eps", replace
more

* Simulated nonemployment and employment (min max tariffs), finding rate and reallocation failure, adjusted for annual nonemployment updating (pnadinfer_ratio_nonempl_empl)
gen simulmin_ratediff = simulmin_indhire - simulmin_inddspl
gen simulminpnad_totempl = pnad_totempl if ano<=1991
replace simulminpnad_totempl = (simulmin_ratediff[_n-1] - ratediff[_n-1])*simulminpnad_totempl[_n-1] + pnad_totempl if ano>=1991
gen simulminpnad_totnonempl = pnad_totnonempl if ano<=1991
replace simulminpnad_totnonempl = -(simulmin_ratediff[_n-1] - ratediff[_n-1])*simulminpnad_totempl[_n-1] + pnad_totnonempl if ano>=1991
gen simulminpnad_indfind = ( simulmin_indhire / (simulminpnad_totnonempl/simulminpnad_totempl) ) / pnadinfer_ratio_nonempl_empl
replace simulminpnad_indfind = simulminpnad_indfind[_n-1] if ano>1997
replace simulminpnad_indfind = infer_indfind if ano<=1990
gen simulminpnad_indnorloc = (1-simulminpnad_indfind)*(1-simulminpnad_indfind[_n+1])*(1-simulminpnad_indfind[_n+2])*(1-simulminpnad_indfind[_n+3])
gen simulmax_ratediff = simulmax_indhire - simulmax_inddspl
gen simulmaxpnad_totempl = pnad_totempl if ano<=1991
replace simulmaxpnad_totempl = (simulmax_ratediff[_n-1] - ratediff[_n-1])*simulmaxpnad_totempl[_n-1] + pnad_totempl if ano>=1991
gen simulmaxpnad_totnonempl = pnad_totnonempl if ano<=1991
replace simulmaxpnad_totnonempl = -(simulmax_ratediff[_n-1] - ratediff[_n-1])*simulmaxpnad_totempl[_n-1] + pnad_totnonempl if ano>=1991
gen simulmaxpnad_indfind = ( simulmax_indhire / (simulmaxpnad_totnonempl/simulmaxpnad_totempl) ) / pnadinfer_ratio_nonempl_empl
replace simulmaxpnad_indfind = simulmaxpnad_indfind[_n-1] if ano>1997
replace simulmaxpnad_indfind = infer_indfind if ano<=1990
gen simulmaxpnad_indnorloc = (1-simulmaxpnad_indfind)*(1-simulmaxpnad_indfind[_n+1])*(1-simulmaxpnad_indfind[_n+2])*(1-simulmaxpnad_indfind[_n+3])
graph twoway connected simulpnad_indfind simulminpnad_indfind simulmaxpnad_indfind infer_indfind ano if ano>=1990 & ano<=`finlyr', xlab(1990/`finlyr') ytitle("Job Finding Rates") legend( label(1 "PNAD Sim. 1990 Tariff") label(2 "PNAD Sim. Piecemeal") label(3 "PNAD Sim. Shock Therapy") label(4 "Observed (implied)") ) graphregion(color(white)) scheme(sj) msymbol(T D C i) clpattern(dot dash_dot dash solid)
graph export "brazrloc/graphs/v4/natl/simul/simulpnad-indfind-`dur'm-annual.eps", replace
more

* Simulated reallocation durations (90 min max tariffs), adjusted for "exaggeration ratio" (ratio_mo2rehir)
gen simuladd_mo2rehir  = (1/ratio_mo2rehir) * ( 0*simuladd_indfind + 1*(1-simuladd_indfind)*simuladd_indfind[_n+1] + 2*(1-simuladd_indfind)*(1-simuladd_indfind[_n+1])*simuladd_indfind[_n+2] + 3*(1-simuladd_indfind)*(1-simuladd_indfind[_n+1])*(1-simuladd_indfind[_n+2])*simuladd_indfind[_n+3] ) * 12 / (1-simuladd_indnorloc)
gen simulfix_mo2rehir  = (1/ratio_mo2rehir) * ( 0*simulfix_indfind + 1*(1-simulfix_indfind)*simulfix_indfind[_n+1] + 2*(1-simulfix_indfind)*(1-simulfix_indfind[_n+1])*simulfix_indfind[_n+2] + 3*(1-simulfix_indfind)*(1-simulfix_indfind[_n+1])*(1-simulfix_indfind[_n+2])*simulfix_indfind[_n+3] ) * 12 / (1-simulfix_indnorloc)
gen simulvar_mo2rehir  = (1/ratio_mo2rehir) * ( 0*simulvar_indfind + 1*(1-simulvar_indfind)*simulvar_indfind[_n+1] + 2*(1-simulvar_indfind)*(1-simulvar_indfind[_n+1])*simulvar_indfind[_n+2] + 3*(1-simulvar_indfind)*(1-simulvar_indfind[_n+1])*(1-simulvar_indfind[_n+2])*simulvar_indfind[_n+3] ) * 12 / (1-simulvar_indnorloc)
gen simulpnad_mo2rehir = (1/ratio_mo2rehir) * ( 0*simulpnad_indfind + 1*(1-simulpnad_indfind)*simulpnad_indfind[_n+1] + 2*(1-simulpnad_indfind)*(1-simulpnad_indfind[_n+1])*simulpnad_indfind[_n+2] + 3*(1-simulpnad_indfind)*(1-simulpnad_indfind[_n+1])*(1-simulpnad_indfind[_n+2])*simulpnad_indfind[_n+3] ) * 12 / (1-simulpnad_indnorloc)
gen simulminpnad_mo2rehir = (1/ratio_mo2rehir) * ( 0*simulminpnad_indfind + 1*(1-simulminpnad_indfind)*simulminpnad_indfind[_n+1] + 2*(1-simulminpnad_indfind)*(1-simulminpnad_indfind[_n+1])*simulminpnad_indfind[_n+2] + 3*(1-simulminpnad_indfind)*(1-simulminpnad_indfind[_n+1])*(1-simulminpnad_indfind[_n+2])*simulminpnad_indfind[_n+3] ) * 12 / (1-simulminpnad_indnorloc)
gen simulmaxpnad_mo2rehir = (1/ratio_mo2rehir) * ( 0*simulmaxpnad_indfind + 1*(1-simulmaxpnad_indfind)*simulmaxpnad_indfind[_n+1] + 2*(1-simulmaxpnad_indfind)*(1-simulmaxpnad_indfind[_n+1])*simulmaxpnad_indfind[_n+2] + 3*(1-simulmaxpnad_indfind)*(1-simulmaxpnad_indfind[_n+1])*(1-simulmaxpnad_indfind[_n+2])*simulmaxpnad_indfind[_n+3] ) * 12 / (1-simulmaxpnad_indnorloc)

* Graph simulation: reallocation failures
preserve
drop if ano>=1998
gen _simulfix_indnorloc = simulfix_indnorloc if ano==1989 | ano==1992 | ano==1997
gen _simulvar_indnorloc = simulvar_indnorloc if ano==1989 | ano==1992 | ano==1997
gen _simulpnad_indnorloc = simulpnad_indnorloc if ano==1989 | ano==1992 | ano==1997
gen _simulminpnad_indnorloc = simulminpnad_indnorloc if ano==1989 | ano==1992
gen _simulmaxpnad_indnorloc = simulmaxpnad_indnorloc if ano==1989 | ano==1992
gen _indnorloc = indnorloc if ano==1989 | ano==1992 | ano==1997
gen _simulmax_tarfoutp_drk = simulmax_tarfoutp if ano>=1990 & ano<=1993
gen _simulmax_tarfoutp_lgt = simulmax_tarfoutp if ano>=1994 & ano<=1997
replace ano = ano-1900
format tarfoutp simul_tarfoutp simulfix_indnorloc simulvar_indnorloc simulpnad_indnorloc simulminpnad_indnorloc simulmaxpnad_indnorloc indnorloc _simulfix_indnorloc _simulvar_indnorloc _simulpnad_indnorloc _simulminpnad_indnorloc _simulmaxpnad_indnorloc _indnorloc _simulmax_tarfoutp_drk _simulmax_tarfoutp_lgt %9.2f
twoway bar simul_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || connected simulfix_indnorloc indnorloc ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _simulfix_indnorloc _indnorloc ano, mlabel(_simulfix_indnorloc _indnorloc) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected indnorloc ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(.05 .25)) ytitle("Nonemployed without new job (share)", axis(2)) ylabel(.05(.05).25, axis(2)) yline(.15 .175 .2 .225 .25, axis(2) lcolor(gs14)) legend( order(1 2 4 5) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(4 "Counterfct. Realloc. Failures") label(5 "Realloc. Failures") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/simulfix-tarfoutp-indnorloc48-86-98.eps", replace
more
twoway bar simul_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || connected simulvar_indnorloc indnorloc ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _simulvar_indnorloc _indnorloc ano, mlabel(_simulvar_indnorloc _indnorloc) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected indnorloc ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(.05 .25)) ytitle("Nonemployed without new job (share)", axis(2)) ylabel(.05(.05).25, axis(2)) yline(.15 .175 .2 .225 .25, axis(2) lcolor(gs14)) legend( order(1 2 4 5) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(4 "Counterfct. Realloc. Failures") label(5 "Realloc. Failures") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/simulvar-tarfoutp-indnorloc48-86-98.eps", replace
more
twoway bar simul_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || connected simulpnad_indnorloc indnorloc ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _simulpnad_indnorloc _indnorloc ano, mlabel(_simulpnad_indnorloc _indnorloc) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected indnorloc ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(.05 .25)) ytitle("Nonemployed without new job (share)", axis(2)) ylabel(.05(.05).25, axis(2)) yline(.15 .175 .2 .225 .25, axis(2) lcolor(gs14)) legend( order(1 2 4 5) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(4 "Counterfct. Realloc. Failures") label(5 "Realloc. Failures") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/simulpnad-tarfoutp-indnorloc48-86-98.eps", replace
more
twoway bar simulmin_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || connected simulminpnad_indnorloc indnorloc ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _simulminpnad_indnorloc _indnorloc ano, mlabel(_simulminpnad_indnorloc _indnorloc) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected indnorloc ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(.05 .25)) ytitle("Nonemployed without new job (share)", axis(2)) ylabel(.05(.05).25, axis(2)) yline(.15 .175 .2 .225 .25, axis(2) lcolor(gs14)) legend( order(1 2 4 5) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(4 "Counterfct. Realloc. Failures") label(5 "Realloc. Failures") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/simulminpnad-tarfoutp-indnorloc48-86-98.eps", replace
more
twoway bar simulmax_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || bar _simulmax_tarfoutp_drk ano, bcolor(gs12) yaxis(1) || connected simulmaxpnad_indnorloc indnorloc ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _simulmaxpnad_indnorloc _indnorloc ano, mlabel(_simulmaxpnad_indnorloc _indnorloc) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected indnorloc ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(.05 .25)) ytitle("Nonemployed without new job (share)", axis(2)) ylabel(.05(.05).25, axis(2)) yline(.15 .175 .2 .225 .25, axis(2) lcolor(gs14)) legend( order(1 2 5 6) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(5 "Counterfct. Realloc. Failures") label(6 "Realloc. Failures") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/simulmaxpnad-tarfoutp-indnorloc48-86-98.eps", replace
more
restore

* Graph simulation: reallocation durations
preserve
drop if ano>=1998
gen _simulfix_mo2rehir = simulfix_mo2rehir if ano==1989 | ano==1992 | ano==1997
gen _simulvar_mo2rehir = simulvar_mo2rehir if ano==1989 | ano==1992 | ano==1997
gen _simulpnad_mo2rehir = simulpnad_mo2rehir if ano==1989 | ano==1992 | ano==1997
gen _simulminpnad_mo2rehir = simulminpnad_mo2rehir if ano==1989 | ano==1992
gen _simulmaxpnad_mo2rehir = simulmaxpnad_mo2rehir if ano==1989 | ano==1992
gen _mo2rehir = mo2rehir if ano==1989 | ano==1992 | ano==1997
gen _simulmax_tarfoutp_drk = simulmax_tarfoutp if ano>=1990 & ano<=1993
gen _simulmax_tarfoutp_lgt = simulmax_tarfoutp if ano>=1994 & ano<=1997
replace ano = ano-1900
format tarfoutp simul_tarfoutp simulfix_mo2rehir simulvar_mo2rehir simulpnad_mo2rehir simulminpnad_mo2rehir simulmaxpnad_mo2rehir mo2rehir _simulfix_mo2rehir _simulvar_mo2rehir _simulpnad_mo2rehir _simulminpnad_mo2rehir _simulmaxpnad_mo2rehir _mo2rehir _simulmax_tarfoutp_drk _simulmax_tarfoutp_lgt %9.2f
twoway bar simul_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || connected simulfix_mo2rehir mo2rehir ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _simulfix_mo2rehir _mo2rehir ano, mlabel(_simulfix_mo2rehir _mo2rehir) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected mo2rehir ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(5 10)) ytitle("Nonemployment until first new job (months)", axis(2)) yline(6 7 8 9 10, axis(2) lcolor(gs14)) yline(.15 .175 .2 .225 .25, axis(2) lcolor(gs14)) legend( order(1 2 4 5) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(4 "Counterfct. Realloc. Durations") label(5 "Realloc. Durations") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/simulfix-tarfoutp-mo2rehir48-86-98.eps", replace
more
twoway bar simul_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || connected simulvar_mo2rehir mo2rehir ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _simulvar_mo2rehir _mo2rehir ano, mlabel(_simulvar_mo2rehir _mo2rehir) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected mo2rehir ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(5 10)) ytitle("Nonemployment until first new job (months)", axis(2)) yline(6 7 8 9 10, axis(2) lcolor(gs14)) legend( order(1 2 4 5) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(4 "Counterfct. Realloc. Durations") label(5 "Realloc. Durations") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/simulvar-tarfoutp-mo2rehir48-86-98.eps", replace
more
twoway bar simul_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || connected simulpnad_mo2rehir mo2rehir ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _simulpnad_mo2rehir _mo2rehir ano, mlabel(_simulpnad_mo2rehir _mo2rehir) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected mo2rehir ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(5 10)) ytitle("Nonemployment until first new job (months)", axis(2)) yline(6 7 8 9 10, axis(2) lcolor(gs14)) legend( order(1 2 4 5) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(4 "Counterfct. Realloc. Durations") label(5 "Realloc. Durations") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/simulpnad-tarfoutp-mo2rehir48-86-98.eps", replace
more
twoway bar simulmin_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || connected simulminpnad_mo2rehir mo2rehir ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _simulminpnad_mo2rehir _mo2rehir ano, mlabel(_simulminpnad_mo2rehir _mo2rehir) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected mo2rehir ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(5 10)) ytitle("Nonemployment until first new job (months)", axis(2)) yline(6 7 8 9 10, axis(2) lcolor(gs14)) legend( order(1 2 4 5) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(4 "Counterfct. Realloc. Durations") label(5 "Realloc. Durations") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/simulminpnad-tarfoutp-mo2rehir48-86-98.eps", replace
more
twoway bar simulmax_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || bar _simulmax_tarfoutp_drk ano, bcolor(gs12) yaxis(1) || connected simulmaxpnad_mo2rehir mo2rehir ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _simulmaxpnad_mo2rehir _mo2rehir ano, mlabel(_simulmaxpnad_mo2rehir _mo2rehir) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected mo2rehir ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(5 10)) ytitle("Nonemployment until first new job (months)", axis(2)) yline(6 7 8 9 10, axis(2) lcolor(gs14)) legend( order(1 2 5 6) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(5 "Counterfct. Realloc. Durations") label(6 "Realloc. Durations") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/simulmaxpnad-tarfoutp-mo2rehir48-86-98.eps", replace
more
restore

* Simulated nonemployment and employment (90 min max tariffs), adjusted for cumulative nonemployment updating (pnadinfer_ratio_nonempl_empl)
gen cumsimulpnad_totempl = pnad_totempl if ano<=1991
replace cumsimulpnad_totempl = (simul_ratediff[_n-1] - ratediff[_n-1])*cumsimulpnad_totempl[_n-1] + cumsimulpnad_totempl[_n-1] if ano>=1991
gen cumsimulpnad_totnonempl = pnad_totnonempl if ano<=1991
replace cumsimulpnad_totnonempl = -(simul_ratediff[_n-1] - ratediff[_n-1])*cumsimulpnad_totempl[_n-1] + cumsimulpnad_totnonempl[_n-1] if ano>=1991
gen cumsimulminpnad_totempl = pnad_totempl if ano<=1991
replace cumsimulminpnad_totempl = (simulmin_ratediff[_n-1] - ratediff[_n-1])*cumsimulminpnad_totempl[_n-1] + cumsimulminpnad_totempl[_n-1] if ano>=1991
gen cumsimulminpnad_totnonempl = pnad_totnonempl if ano<=1991
replace cumsimulminpnad_totnonempl = -(simulmin_ratediff[_n-1] - ratediff[_n-1])*cumsimulminpnad_totempl[_n-1] + cumsimulminpnad_totnonempl[_n-1] if ano>=1991
gen cumsimulmaxpnad_totempl = pnad_totempl if ano<=1991
replace cumsimulmaxpnad_totempl = (simulmax_ratediff[_n-1] - ratediff[_n-1])*cumsimulmaxpnad_totempl[_n-1] + cumsimulmaxpnad_totempl[_n-1] if ano>=1991
gen cumsimulmaxpnad_totnonempl = pnad_totnonempl if ano<=1991
replace cumsimulmaxpnad_totnonempl = -(simulmax_ratediff[_n-1] - ratediff[_n-1])*cumsimulmaxpnad_totempl[_n-1] + cumsimulmaxpnad_totnonempl[_n-1] if ano>=1991
gen cumsimulpnad_indfind = ( simul_indhire / (cumsimulpnad_totnonempl/cumsimulpnad_totempl) ) / pnadinfer_ratio_nonempl_empl
replace cumsimulpnad_indfind = cumsimulpnad_indfind[_n-1] if ano>1997
replace cumsimulpnad_indfind = infer_indfind if ano<=1990
gen cumsimulpnad_indnorloc = (1-cumsimulpnad_indfind)*(1-cumsimulpnad_indfind[_n+1])*(1-cumsimulpnad_indfind[_n+2])*(1-cumsimulpnad_indfind[_n+3])
gen cumsimulminpnad_indfind = ( simulmin_indhire / (cumsimulminpnad_totnonempl/cumsimulminpnad_totempl) ) / pnadinfer_ratio_nonempl_empl
replace cumsimulminpnad_indfind = cumsimulminpnad_indfind[_n-1] if ano>1997
replace cumsimulminpnad_indfind = infer_indfind if ano<=1990
gen cumsimulminpnad_indnorloc = (1-cumsimulminpnad_indfind)*(1-cumsimulminpnad_indfind[_n+1])*(1-cumsimulminpnad_indfind[_n+2])*(1-cumsimulminpnad_indfind[_n+3])
gen cumsimulmaxpnad_indfind = ( simulmax_indhire / (cumsimulmaxpnad_totnonempl/cumsimulmaxpnad_totempl) ) / pnadinfer_ratio_nonempl_empl
replace cumsimulmaxpnad_indfind = cumsimulmaxpnad_indfind[_n-1] if ano>1997
replace cumsimulmaxpnad_indfind = infer_indfind if ano<=1990
gen cumsimulmaxpnad_indnorloc = (1-cumsimulmaxpnad_indfind)*(1-cumsimulmaxpnad_indfind[_n+1])*(1-cumsimulmaxpnad_indfind[_n+2])*(1-cumsimulmaxpnad_indfind[_n+3])
gen cumsimulpnad_mo2rehir = (1/ratio_mo2rehir) * ( 0*cumsimulpnad_indfind + 1*(1-cumsimulpnad_indfind)*cumsimulpnad_indfind[_n+1] + 2*(1-cumsimulpnad_indfind)*(1-cumsimulpnad_indfind[_n+1])*cumsimulpnad_indfind[_n+2] + 3*(1-cumsimulpnad_indfind)*(1-cumsimulpnad_indfind[_n+1])*(1-cumsimulpnad_indfind[_n+2])*cumsimulpnad_indfind[_n+3] ) * 12 / (1-cumsimulpnad_indnorloc)
gen cumsimulminpnad_mo2rehir = (1/ratio_mo2rehir) * ( 0*cumsimulminpnad_indfind + 1*(1-cumsimulminpnad_indfind)*cumsimulminpnad_indfind[_n+1] + 2*(1-cumsimulminpnad_indfind)*(1-cumsimulminpnad_indfind[_n+1])*cumsimulminpnad_indfind[_n+2] + 3*(1-cumsimulminpnad_indfind)*(1-cumsimulminpnad_indfind[_n+1])*(1-cumsimulminpnad_indfind[_n+2])*cumsimulminpnad_indfind[_n+3] ) * 12 / (1-cumsimulminpnad_indnorloc)
gen cumsimulmaxpnad_mo2rehir = (1/ratio_mo2rehir) * ( 0*cumsimulmaxpnad_indfind + 1*(1-cumsimulmaxpnad_indfind)*cumsimulmaxpnad_indfind[_n+1] + 2*(1-cumsimulmaxpnad_indfind)*(1-cumsimulmaxpnad_indfind[_n+1])*cumsimulmaxpnad_indfind[_n+2] + 3*(1-cumsimulmaxpnad_indfind)*(1-cumsimulmaxpnad_indfind[_n+1])*(1-cumsimulmaxpnad_indfind[_n+2])*cumsimulmaxpnad_indfind[_n+3] ) * 12 / (1-cumsimulmaxpnad_indnorloc)
graph twoway connected cumsimulpnad_totempl cumsimulpnad_totnonempl ano if ano>=1988 & ano<=`finlyr', xlab(1988/`finlyr') ytitle("Million persons") legend( label(1 "Simul. PNAD Employment") label(2 "Simul. PNAD Nonempl.") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/cumsimulpnad-totnonempl`dur'm-annual.eps", replace
more
graph twoway connected cumsimulpnad_totempl cumsimulpnad_totnonempl ano if ano>=1990 & ano<=`finlyr', xlab(1990/`finlyr') ylab(10(10)60)  ytitle("Million persons") legend( label(1 "Simul. PNAD Employment") label(2 "Simul. PNAD Nonempl.") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/cumsimulpnad-totnonempl`dur'm-annual-1990.eps", replace
more
graph twoway connected cumsimulminpnad_totempl cumsimulminpnad_totnonempl ano if ano>=1988 & ano<=`finlyr', xlab(1988/`finlyr') ytitle("Million persons") legend( label(1 "Simul. PNAD Employment") label(2 "Simul. PNAD Nonempl.") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/cumsimulminpnad-totnonempl`dur'm-annual.eps", replace
more
graph twoway connected cumsimulminpnad_totempl cumsimulminpnad_totnonempl ano if ano>=1990 & ano<=`finlyr', xlab(1990/`finlyr') ylab(10(10)60)  ytitle("Million persons") legend( label(1 "Simul. PNAD Employment") label(2 "Simul. PNAD Nonempl.") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/cumsimulminpnad-totnonempl`dur'm-annual-1990.eps", replace
more
graph twoway connected cumsimulmaxpnad_totempl cumsimulmaxpnad_totnonempl ano if ano>=1988 & ano<=`finlyr', xlab(1988/`finlyr') ytitle("Million persons") legend( label(1 "Simul. PNAD Employment") label(2 "Simul. PNAD Nonempl.") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/cumsimulmaxpnad-totnonempl`dur'm-annual.eps", replace
more
graph twoway connected cumsimulmaxpnad_totempl cumsimulmaxpnad_totnonempl ano if ano>=1990 & ano<=`finlyr', xlab(1990/`finlyr') ylab(10(10)60)  ytitle("Million persons") legend( label(1 "Simul. PNAD Employment") label(2 "Simul. PNAD Nonempl.") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/cumsimulmaxpnad-totnonempl`dur'm-annual-1990.eps", replace
more
graph twoway connected simulminpnad_totempl simulminpnad_totnonempl ano if ano>=1988 & ano<=`finlyr', xlab(1988/`finlyr') ytitle("Million persons") legend( label(1 "Simul. PNAD Employment") label(2 "Simul. PNAD Nonempl.") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/simulminpnad-totnonempl`dur'm-annual.eps", replace
more
graph twoway connected simulminpnad_totempl simulminpnad_totnonempl ano if ano>=1990 & ano<=`finlyr', xlab(1990/`finlyr') ylab(10(10)60)  ytitle("Million persons") legend( label(1 "Simul. PNAD Employment") label(2 "Simul. PNAD Nonempl.") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/simulminpnad-totnonempl`dur'm-annual-1990.eps", replace
more
graph twoway connected simulmaxpnad_totempl simulmaxpnad_totnonempl ano if ano>=1988 & ano<=`finlyr', xlab(1988/`finlyr') ytitle("Million persons") legend( label(1 "Simul. PNAD Employment") label(2 "Simul. PNAD Nonempl.") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/simulmaxpnad-totnonempl`dur'm-annual.eps", replace
more
graph twoway connected simulmaxpnad_totempl simulmaxpnad_totnonempl ano if ano>=1990 & ano<=`finlyr', xlab(1990/`finlyr') ylab(10(10)60)  ytitle("Million persons") legend( label(1 "Simul. PNAD Employment") label(2 "Simul. PNAD Nonempl.") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/simulmaxpnad-totnonempl`dur'm-annual-1990.eps", replace
more
graph twoway connected cumsimulpnad_indfind cumsimulminpnad_indfind cumsimulmaxpnad_indfind infer_indfind ano if ano>=1990 & ano<=`finlyr', xlab(1990/`finlyr') ytitle("Job Finding Rates") legend( label(1 "Cumul. Sim. 1990 Tariff") label(2 "Cumul. Sim. Piecemeal") label(3 "Cumul. Sim. Shock Therapy") label(4 "Observed (implied)") ) graphregion(color(white)) scheme(sj) msymbol(T D C i) clpattern(dot dash_dot dash solid)
graph export "brazrloc/graphs/v4/natl/simul/cumsimul-indfind-`dur'm-annual.eps", replace
more

* Graph cumulative simulation: reallocation failures
preserve
drop if ano>=1998
gen _cumsimulpnad_indnorloc = cumsimulpnad_indnorloc if ano==1989 | ano==1992 | ano==1997
gen _cumsimulminpnad_indnorloc = cumsimulminpnad_indnorloc if ano==1989 | ano==1992
gen _cumsimulmaxpnad_indnorloc = cumsimulmaxpnad_indnorloc if ano==1989 | ano==1992
gen _indnorloc = indnorloc if ano==1989 | ano==1992 | ano==1997
gen _simulmax_tarfoutp_drk = simulmax_tarfoutp if ano>=1990 & ano<=1993
gen _simulmax_tarfoutp_lgt = simulmax_tarfoutp if ano>=1994 & ano<=1997
replace ano = ano-1900
format tarfoutp simul_tarfoutp cumsimulpnad_indnorloc cumsimulminpnad_indnorloc cumsimulmaxpnad_indnorloc indnorloc _cumsimulpnad_indnorloc _cumsimulminpnad_indnorloc _cumsimulmaxpnad_indnorloc _indnorloc _simulmax_tarfoutp_drk _simulmax_tarfoutp_lgt %9.2f
twoway bar simul_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || connected cumsimulpnad_indnorloc indnorloc ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _cumsimulpnad_indnorloc _indnorloc ano, mlabel(_cumsimulpnad_indnorloc _indnorloc) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected indnorloc ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(.05 .25)) ytitle("Nonemployed without new job (share)", axis(2)) ylabel(.05(.05).25, axis(2)) yline(.15 .175 .2 .225 .25, axis(2) lcolor(gs14)) legend( order(1 2 4 5) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(4 "Counterfct. Realloc. Failures") label(5 "Realloc. Failures") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/cumsimulpnad-tarfoutp-indnorloc48-86-98.eps", replace
more
twoway bar simulmin_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || connected cumsimulminpnad_indnorloc indnorloc ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _cumsimulminpnad_indnorloc _indnorloc ano, mlabel(_cumsimulminpnad_indnorloc _indnorloc) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected indnorloc ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(.05 .25)) ytitle("Nonemployed without new job (share)", axis(2)) ylabel(.05(.05).25, axis(2)) yline(.15 .175 .2 .225 .25, axis(2) lcolor(gs14)) legend( order(1 2 4 5) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(4 "Counterfct. Realloc. Failures") label(5 "Realloc. Failures") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/cumsimulminpnad-tarfoutp-indnorloc48-86-98.eps", replace
more
twoway bar simulmax_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || bar _simulmax_tarfoutp_drk ano, bcolor(gs12) yaxis(1) || connected cumsimulmaxpnad_indnorloc indnorloc ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _cumsimulmaxpnad_indnorloc _indnorloc ano, mlabel(_cumsimulmaxpnad_indnorloc _indnorloc) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected indnorloc ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(.05 .25)) ytitle("Nonemployed without new job (share)", axis(2)) ylabel(.05(.05).25, axis(2)) yline(.15 .175 .2 .225 .25, axis(2) lcolor(gs14)) legend( order(1 2 5 6) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(5 "Counterfct. Realloc. Failures") label(6 "Realloc. Failures") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/cumsimulmaxpnad-tarfoutp-indnorloc48-86-98.eps", replace
more
restore

* Graph cumulative cumsimulation: reallocation durations
preserve
drop if ano>=1998
gen _cumsimulpnad_mo2rehir = cumsimulpnad_mo2rehir if ano==1989 | ano==1992 | ano==1997
gen _cumsimulminpnad_mo2rehir = cumsimulminpnad_mo2rehir if ano==1989 | ano==1992
gen _cumsimulmaxpnad_mo2rehir = cumsimulmaxpnad_mo2rehir if ano==1989 | ano==1992
gen _mo2rehir = mo2rehir if ano==1989 | ano==1992 | ano==1997
gen _simulmax_tarfoutp_drk = simulmax_tarfoutp if ano>=1990 & ano<=1993
gen _simulmax_tarfoutp_lgt = simulmax_tarfoutp if ano>=1994 & ano<=1997
replace ano = ano-1900
format tarfoutp simul_tarfoutp cumsimulpnad_mo2rehir cumsimulminpnad_mo2rehir cumsimulmaxpnad_mo2rehir mo2rehir _cumsimulpnad_mo2rehir _cumsimulminpnad_mo2rehir _cumsimulmaxpnad_mo2rehir _mo2rehir _simulmax_tarfoutp_drk _simulmax_tarfoutp_lgt %9.2f
twoway bar simul_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || connected cumsimulpnad_mo2rehir mo2rehir ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _cumsimulpnad_mo2rehir _mo2rehir ano, mlabel(_cumsimulpnad_mo2rehir _mo2rehir) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected mo2rehir ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(5 10)) ytitle("Nonemployment until first new job (months)", axis(2)) yline(6 7 8 9 10, axis(2) lcolor(gs14)) legend( order(1 2 4 5) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(4 "Counterfct. Realloc. Durations") label(5 "Realloc. Durations") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/cumsimulpnad-tarfoutp-mo2rehir48-86-98.eps", replace
more
twoway bar simulmin_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || connected cumsimulminpnad_mo2rehir mo2rehir ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _cumsimulminpnad_mo2rehir _mo2rehir ano, mlabel(_cumsimulminpnad_mo2rehir _mo2rehir) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected mo2rehir ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(5 10)) ytitle("Nonemployment until first new job (months)", axis(2)) yline(6 7 8 9 10, axis(2) lcolor(gs14)) legend( order(1 2 4 5) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(4 "Counterfct. Realloc. Durations") label(5 "Realloc. Durations") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/cumsimulminpnad-tarfoutp-mo2rehir48-86-98.eps", replace
more
twoway bar simulmax_tarfoutp tarfoutp ano, bcolor(gs12 gs9) yaxis(1) || bar _simulmax_tarfoutp_drk ano, bcolor(gs12) yaxis(1) || connected cumsimulmaxpnad_mo2rehir mo2rehir ano, yaxis(2) msymbol(O T) mcolor(gs6 gs6) clpattern(longdash solid) || sc tarfoutp ano, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _cumsimulmaxpnad_mo2rehir _mo2rehir ano, mlabel(_cumsimulmaxpnad_mo2rehir _mo2rehir) mlabposition(2 2) mlabcolor(black black) msymbol(i i) yaxis(2) || connected mo2rehir ano, yaxis(2) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(5 10)) ytitle("Nonemployment until first new job (months)", axis(2)) yline(6 7 8 9 10, axis(2) lcolor(gs14)) legend( order(1 2 5 6) label(1 "Counterfct. Prd. Mkt. Tariff") label(2 "Prd. Mkt. Trf.") label(5 "Counterfct. Realloc. Durations") label(6 "Realloc. Durations") ) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/natl/simul/cumsimulmaxpnad-tarfoutp-mo2rehir48-86-98.eps", replace
more
restore

log close
